@@ -33,7 +33,8 @@ PYTHON2=$(which python || true)
 PYTHON3=$(which python3 || true)
 PYTHON=${PYTHON2:-$PYTHON3}
 BASE_PIP_URL=${BASE_PIP_URL:-"https://pypi.python.org/simple"}
-VIRTUALENV_191_URL="https://raw.github.com/pypa/virtualenv/1.9.1/virtualenv.py"
+VIRTUALENV_VERSION="15.1.0"
+VIRTUALENV_URL="https://raw.github.com/pypa/virtualenv/$VIRTUALENV_VERSION/virtualenv.py"
 
 RALLY_GIT_URL="https://git.openstack.org/openstack/rally"
 RALLY_GIT_BRANCH="master"
@@ -246,41 +247,40 @@ __EOF__
     fi
 }
 
-have_sw_package () {
-    # instead of guessing which distribution this is, we check for the
-    # package manager name as it basically identifies the distro
-    if have_command dpkg; then
-        (dpkg -l "$1" | egrep -q ^i ) >/dev/null 2>/dev/null
-    elif have_command rpm; then
-        rpm -q "$1" >/dev/null 2>/dev/null
+which_missing_packages () {
+    if [ ! -f bindep.txt ]; then
+        abort $EX_PROTOCOL \
+            "bindep.txt not found. Unable to find missing packages."
     fi
+    require_command "bindep"
+    require_command "lsb_release"
+    echo "$(bindep -b | tr '\n' ' ')"
 }
 
-which_missing_packages () {
-    local missing=''
-    for pkgname in "$@"; do
-        if have_sw_package "$pkgname"; then
-            continue;
-        else
-            missing="$missing $pkgname"
-        fi
-    done
+which_missing_commands () {
+    # These commands are required to run install_rally.sh
+    local missing=""
+    if ! have_command "wget"; then
+        missing="wget"
+    fi
+    if ! have_command "git"; then
+        missing="$missing git"
+    fi
+    if ! have_command "pip"; then
+        missing="$missing python-pip"
+    fi
     echo "$missing"
 }
 
+
 # Download command
 download() {
     wget -nv $VERBOSE --no-check-certificate -O "$@";
 }
 
-install_required_sw () {
-    # instead of guessing which distribution this is, we check for the
-    # package manager name as it basically identifies the distro
-    local missing pkg_manager
+get_pkg_manager () {
     if have_command apt-get; then
         # Debian/Ubuntu
-        missing=$(which_missing_packages build-essential libssl-dev libffi-dev python-dev libxml2-dev libxslt1-dev libpq-dev git wget)
-
         if [ "$ASKCONFIRMATION" -eq 0 ]; then
             pkg_manager="apt-get install --yes"
         else
@@ -288,8 +288,6 @@ install_required_sw () {
         fi
     elif have_command dnf; then
         # dnf based RHEL/CentOS/Fedora
-        missing=$(which_missing_packages gcc libffi-devel python-devel openssl-devel gmp-devel libxml2-devel libxslt-devel postgresql-devel redhat-rpm-config git wget)
-
         if [ "$ASKCONFIRMATION" -eq 0 ]; then
             pkg_manager="dnf install -y"
         else
@@ -297,8 +295,6 @@ install_required_sw () {
         fi
     elif have_command yum; then
         # yum based RHEL/CentOS/Fedora
-        missing=$(which_missing_packages gcc libffi-devel python-devel openssl-devel gmp-devel libxml2-devel libxslt-devel postgresql-devel redhat-rpm-config git wget)
-
         if [ "$ASKCONFIRMATION" -eq 0 ]; then
             pkg_manager="yum install -y"
         else
@@ -306,8 +302,6 @@ install_required_sw () {
         fi
     elif have_command zypper; then
         # SuSE
-        missing=$(which_missing_packages gcc libffi48-devel python-devel openssl-devel gmp-devel libxml2-devel libxslt-devel postgresql93-devel git wget)
-
         if [ "$ASKCONFIRMATION" -eq 0 ]; then
             pkg_manager="zypper -n --no-gpg-checks --non-interactive install --auto-agree-with-licenses"
         else
@@ -317,9 +311,15 @@ install_required_sw () {
         # MacOSX maybe?
         echo "Cannot determine what package manager this system has, so I cannot check if requisite software is installed. I'm proceeding anyway, but you may run into errors later."
     fi
-    if ! have_command pip; then
-        missing="$missing python-pip"
-    fi
+    echo $pkg_manager
+}
+
+install_required_sw () {
+    # instead of guessing which distribution this is, we check for the
+    # package manager name as it basically identifies the distro
+    local missing pkg_manager
+    missing=$1
+    pkg_manager=$(get_pkg_manager)
 
     if [ -n "$missing" ]; then
         cat <<__EOF__
@@ -356,7 +356,7 @@ __EOF__
                         fi
                     fi
                 fi
-                if ! $pkg_manager $missing; then
+                if [ -n "$missing" ] && ! $pkg_manager $missing; then
                     abort $EX_UNAVAILABLE "Error while installing $missing"
                 fi
                 # installation successful
@@ -417,21 +417,28 @@ __EOF__
     fi
 
     # Use the latest virtualenv that can use `.tar.gz` files
-    VIRTUALENV_DST="$DESTDIR/virtualenv-191.py"
+    VIRTUALENV_DST="$DESTDIR/virtualenv-$VIRTUALENV_VERSION.py"
     mkdir -p "$DESTDIR"
-    download "$VIRTUALENV_DST" "$VIRTUALENV_191_URL"
-    "$PYTHON" "$VIRTUALENV_DST" $VERBOSE -p "$PYTHON" "$DESTDIR"
+    download "$VIRTUALENV_DST" "$VIRTUALENV_URL"
+    "$PYTHON" "$VIRTUALENV_DST" $VERBOSE --no-setuptools --no-pip --no-wheel \
+        -p "$PYTHON" "$DESTDIR"
 
-    cd "${DESTDIR}" && . bin/activate
+    . "$DESTDIR/bin/activate"
 
-    # Setuptools>=0.8 is required to support "wheel" format, otherwise
-    # pip will fail with an error. To be sure, just run upgrade to the
-    # recent version of setuptools
-    download - https://bootstrap.pypa.io/ez_setup.py | python - --insecure\
-        || die ${EX_SOFTWARE}\
-            "Failed to install the latest version of Python 'setuptools'" <<__EOF__
+    download - https://bootstrap.pypa.io/get-pip.py | python -\
+        || die $EX_PROTOCOL \
+        "Error while running get-pip.py" <<__EOF__
 
-The required Python package setuptools could not be installed.
+The required Python package pip could not be installed
+in virtualenv.
+
+__EOF__
+
+    pip install setuptools wheel || die $EX_PROTOCOL \
+        "Error while running 'pip install setuptools wheel'" <<__EOF__
+
+The required Python package setuptools, wheel could not be installed
+in virtualenv.
 
 __EOF__
 }
@@ -637,7 +644,7 @@ __EOF__
 fi
 
 # check and install prerequisites
-install_required_sw
+install_required_sw "$(which_missing_commands)"
 require_python
 
 
@@ -729,7 +736,11 @@ pip install -i "$BASE_PIP_URL" -U 'pip!=8'
 hash -r
 
 # Install dependencies
-pip install -i "$BASE_PIP_URL" pbr 'tox<=1.6.1'
+pip install -i "$BASE_PIP_URL" pbr 'tox<=1.6.1' bindep
+
+# Install binary dependencies
+install_required_sw "$(which_missing_packages)"
+
 # Uninstall possible previous version
 pip uninstall -y rally || true
 # Install rally
