@@ -149,8 +149,9 @@ class _Deployment(object):
         :param deployment: Deployment object
         :returns: Service list
         """
-        # TODO(kun): put this work into objects.Deployment
-        clients = osclients.Clients(objects.Credential(**deployment["admin"]))
+        # TODO(astudenov): put this work into Credential plugins
+        admin = deployment.get_credentials_for("openstack")["admin"]
+        clients = osclients.Clients(objects.Credential(**admin))
         return clients.services()
 
     @staticmethod
@@ -167,8 +168,9 @@ class _Deployment(object):
 
         :returns: Service list
         """
+        # TODO(astudenov): put this work into Credential plugins
         services = cls.service_list(deployment)
-        users = deployment["users"]
+        users = deployment.get_credentials_for("openstack")["users"]
         for endpoint_dict in users:
             osclients.Clients(objects.Credential(**endpoint_dict)).keystone()
 
@@ -297,8 +299,15 @@ class _Task(object):
         :returns: Task object
         """
 
-        deployment_uuid = objects.Deployment.get(deployment)["uuid"]
-        return objects.Task(deployment_uuid=deployment_uuid, tag=tag)
+        deployment = objects.Deployment.get(deployment)
+        if deployment["status"] != consts.DeployStatus.DEPLOY_FINISHED:
+            raise exceptions.DeploymentNotFinishedStatus(
+                name=deployment["name"],
+                uuid=deployment["uuid"],
+                status=deployment["status"])
+
+        return objects.Task(deployment_uuid=deployment["uuid"],
+                            tag=tag)
 
     @classmethod
     def validate(cls, deployment, config, task_instance=None):
@@ -310,8 +319,7 @@ class _Task(object):
         deployment = objects.Deployment.get(deployment)
         task = task_instance or objects.Task(
             deployment_uuid=deployment["uuid"], temporary=True)
-        benchmark_engine = engine.TaskEngine(
-            config, task, admin=deployment["admin"], users=deployment["users"])
+        benchmark_engine = engine.TaskEngine(config, task, deployment)
 
         benchmark_engine.validate()
 
@@ -329,6 +337,7 @@ class _Task(object):
                                      stop when any SLA check for it fails
         """
         deployment = objects.Deployment.get(deployment)
+
         task = task or objects.Task(deployment_uuid=deployment["uuid"])
 
         if task.is_temporary:
@@ -337,8 +346,9 @@ class _Task(object):
 
         LOG.info("Benchmark Task %s on Deployment %s" % (task["uuid"],
                                                          deployment["uuid"]))
+
         benchmark_engine = engine.TaskEngine(
-            config, task, admin=deployment["admin"], users=deployment["users"],
+            config, task, deployment,
             abort_on_sla_failure=abort_on_sla_failure)
 
         try:
@@ -378,7 +388,7 @@ class _Task(object):
             LOG.info(_LI("Waiting until the task stops."))
             finished_stages = [consts.TaskStatus.ABORTED,
                                consts.TaskStatus.FINISHED,
-                               consts.TaskStatus.FAILED]
+                               consts.TaskStatus.CRASHED]
             while objects.Task.get_status(task_uuid) not in finished_stages:
                 time.sleep(1)
 
@@ -398,7 +408,7 @@ class _Task(object):
         elif objects.Task.get_status(task_uuid) in (
                 consts.TaskStatus.ABORTED,
                 consts.TaskStatus.FINISHED,
-                consts.TaskStatus.FAILED):
+                consts.TaskStatus.CRASHED):
             objects.Task.delete_by_uuid(task_uuid, status=None)
         else:
             objects.Task.delete_by_uuid(
@@ -814,6 +824,14 @@ class _Verification(object):
         #                  skip the whole test suites. For example, all tests
         #                  in the class or module.
 
+        deployment = objects.Deployment.get(deployment_id)
+
+        if deployment["status"] != consts.DeployStatus.DEPLOY_FINISHED:
+            raise exceptions.DeploymentNotFinishedStatus(
+                name=deployment["name"],
+                uuid=deployment["uuid"],
+                status=deployment["status"])
+
         verifier = _Verifier.get(verifier_id)
         if verifier.status != consts.VerifierStatus.INSTALLED:
             raise exceptions.RallyException(
@@ -861,15 +879,22 @@ class _Verification(object):
         return verification, results
 
     @classmethod
-    def rerun(cls, verification_uuid, deployment_id=None, failed=False):
+    def rerun(cls, verification_uuid, deployment_id=None, failed=False,
+              tags=None, concurrency=0):
         """Rerun tests from a verification.
 
         :param verification_uuid: Verification UUID
         :param deployment_id: Deployment name or UUID
         :param failed: Rerun only failed tests
+        :param tags: List of tags to assign them to verification
+        :param concurrency: The number of processes to use to run verifier
+            tests
         """
         # TODO(ylobankov): Improve this method in the future: put some
         #                  information about re-run in run_args.
+        run_args = {}
+        if concurrency:
+            run_args["concurrency"] = concurrency
 
         verification = cls.get(verification_uuid)
         tests = verification.tests
@@ -888,8 +913,9 @@ class _Verification(object):
         LOG.info("Re-running %stests from verification (UUID=%s) for "
                  "deployment '%s' (UUID=%s).", "failed " if failed else "",
                  verification.uuid, deployment["name"], deployment["uuid"])
-        return cls.start(verification.verifier_uuid, deployment["uuid"],
-                         load_list=tests)
+        return cls.start(
+            verification.verifier_uuid, deployment["uuid"], load_list=tests,
+            tags=tags, **run_args)
 
     @staticmethod
     def get(verification_uuid):
@@ -989,8 +1015,8 @@ class _DeprecatedAPIClass(object):
         self._cls = cls
 
     def __getattr__(self, attr, default=None):
-        LOG.warn(_LW("'%s' is deprecated since Rally 0.8.0 in favor of "
-                     "'rally.api.API' class.") % self._cls.__name__[1:])
+        LOG.warning(_LW("'%s' is deprecated since Rally 0.8.0 in favor of "
+                        "'rally.api.API' class.") % self._cls.__name__[1:])
         return getattr(self._cls, attr, default)
 
 
