@@ -17,8 +17,10 @@ from __future__ import print_function
 
 import argparse
 import inspect
+import json
 import os
 import sys
+import textwrap
 import warnings
 
 import decorator
@@ -26,21 +28,16 @@ import jsonschema
 from oslo_config import cfg
 from oslo_utils import encodeutils
 import prettytable
-from requests.packages import urllib3
 import six
 import sqlalchemy.exc
 
+from rally import api
 from rally.common.i18n import _
 from rally.common import logging
-from rally.common.plugin import discover
 from rally.common.plugin import info
-from rally.common import version
 from rally import exceptions
 
 
-CONFIG_SEARCH_PATHS = [sys.prefix + "/etc/rally", "~/.rally", "/etc/rally"]
-
-
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 
@@ -49,16 +46,6 @@ LOG = logging.getLogger(__name__)
 MARGIN = 3
 
 
-def find_config_files(path_list):
-    for path in path_list:
-        abspath = os.path.abspath(os.path.expanduser(path))
-        confname = abspath + "/rally.conf"
-        if os.path.isfile(confname):
-            return [confname]
-
-    return None
-
-
 class MissingArgs(Exception):
     """Supplied arguments are not sufficient for calling a function."""
     def __init__(self, missing):
@@ -142,13 +129,12 @@ def print_list(objs, fields, formatters=None, sortby_index=0,
             if field in formatters:
                 row.append(formatters[field](o))
             else:
+                field_name = field
+
                 if normalize_field_names:
-                    if field in mixed_case_fields:
-                        field_name = field.replace(" ", "_")
-                    else:
-                        field_name = field.lower().replace(" ", "_")
-                else:
-                    field_name = field
+                    if field_name not in mixed_case_fields:
+                        field_name = field_name.lower()
+                    field_name = field_name.replace(" ", "_").replace("-", "_")
 
                 if isinstance(o, dict):
                     data = o.get(field_name, "")
@@ -184,6 +170,97 @@ def print_list(objs, fields, formatters=None, sortby_index=0,
         out.write(encodeutils.safe_encode(table_body))
 
 
+def print_dict(obj, fields=None, formatters=None, mixed_case_fields=False,
+               normalize_field_names=False, property_label="Property",
+               value_label="Value", table_label=None, print_header=True,
+               print_border=True, wrap=0, out=sys.stdout):
+    """Print dict as a table.
+
+    :param obj: dict to print
+    :param fields: `dict` of keys to print from d. Defaults to all keys
+    :param formatters: `dict` of callables for field formatting
+    :param mixed_case_fields: fields corresponding to object attributes that
+        have mixed case names (e.g., 'serverId')
+    :param normalize_field_names: If True, field names will be transformed,
+        e.g. "Field Name" -> "field_name", otherwise they will be used
+        unchanged.
+    :param property_label: label of "property" column
+    :param value_label: label of "value" column
+    :param table_label: Label to use as header for the whole table.
+    :param print_header: print table header.
+    :param print_border: print table border.
+    :param out: stream to write output to.
+    """
+    formatters = formatters or {}
+    mixed_case_fields = mixed_case_fields or []
+    if not fields:
+        if isinstance(obj, dict):
+            fields = sorted(obj.keys())
+        else:
+            fields = [name for name in dir(obj)
+                      if (not name.startswith("_") and
+                          not callable(getattr(obj, name)))]
+
+    pt = prettytable.PrettyTable([property_label, value_label], caching=False)
+    pt.align = "l"
+    for field_name in fields:
+        if field_name in formatters:
+            data = formatters[field_name](obj)
+        else:
+            field = field_name
+            if normalize_field_names:
+                if field not in mixed_case_fields:
+                    field = field_name.lower()
+                field = field.replace(" ", "_").replace("-", "_")
+
+            if isinstance(obj, dict):
+                data = obj.get(field, "")
+            else:
+                data = getattr(obj, field, "")
+
+        # convert dict to str to check length
+        if isinstance(data, (dict, list)):
+            data = json.dumps(data)
+        if wrap > 0:
+            data = textwrap.fill(six.text_type(data), wrap)
+        # if value has a newline, add in multiple rows
+        # e.g. fault with stacktrace
+        if (data and
+                isinstance(data, six.string_types) and
+                (r"\n" in data or "\r" in data)):
+            # "\r" would break the table, so remove it.
+            if "\r" in data:
+                data = data.replace("\r", "")
+            lines = data.strip().split(r"\n")
+            col1 = field_name
+            for line in lines:
+                pt.add_row([col1, line])
+                col1 = ""
+        else:
+            if data is None:
+                data = "-"
+            pt.add_row([field_name, data])
+
+    table_body = pt.get_string(header=print_header,
+                               border=print_border) + "\n"
+
+    table_header = ""
+
+    if table_label:
+        table_width = table_body.index("\n")
+        table_header = make_table_header(table_label, table_width)
+        table_header += "\n"
+
+    if six.PY3:
+        if table_header:
+            out.write(encodeutils.safe_encode(table_header).decode())
+        out.write(encodeutils.safe_encode(table_body).decode())
+    else:
+        if table_header:
+            out.write(encodeutils.safe_encode(table_header))
+        out.write(encodeutils.safe_encode(table_body))
+
+
 def make_table_header(table_label, table_width,
                       junction_char="+", horizontal_char="-",
                       vertical_char="|"):
@@ -231,7 +308,7 @@ def make_header(text, size=80, symbol="-"):
     :param symbol: What symbol to use to create header
     """
     header = symbol * size + "\n"
-    header += " %s\n" % text
+    header += "%s\n" % text
     header += symbol * size + "\n"
     return header
 
@@ -362,6 +439,24 @@ def deprecated_args(*args, **kwargs):
     return _decorator
 
 
+def help_group(uuid):
+    """Label cli method with specific group.
+
+    Joining methods by groups allows to compose more user-friendly help
+    messages in CLI.
+
+    :param uuid: Name of group to find common methods. It will be used for
+        sorting groups in help message, so you can start uuid with
+        some number (i.e "1_launcher", "2_management") to put groups in proper
+        order. Note: default group had "0" uuid.
+    """
+
+    def wrapper(func):
+        func.help_group = uuid
+        return func
+    return wrapper
+
+
 def _methods_of(cls):
     """Get all callable methods of a class that don't start with underscore.
 
@@ -373,6 +468,20 @@ def _methods_of(cls):
     all_methods = inspect.getmembers(
         cls, predicate=lambda x: inspect.ismethod(x) or inspect.isfunction(x))
     methods = [m for m in all_methods if not m[0].startswith("_")]
+
+    help_groups = {}
+    for m in methods:
+        group = getattr(m[1], "help_group", "0")
+        help_groups.setdefault(group, []).append(m)
+
+    if len(help_groups) > 1:
+        # we should sort methods by groups
+        methods = []
+        for group in sorted(help_groups.items(), key=lambda x: x[0]):
+            if methods:
+                # None -> empty line between groups
+                methods.append((None, None))
+            methods.extend(group[1])
     return methods
 
 
@@ -386,10 +495,13 @@ def _compose_category_description(category):
         description = doc.strip()
     if descr_pairs:
         description += "\n\nCommands:\n"
-        sublen = lambda item: len(item[0])
+        sublen = lambda item: len(item[0]) if item[0] else 0
         first_column_len = max(map(sublen, descr_pairs)) + MARGIN
         for item in descr_pairs:
-            name = getattr(item[1], "alias", item[0])
+            if item[0] is None:
+                description += "\n"
+                continue
+            name = getattr(item[1], "alias", item[0].replace("_", "-"))
             if item[1].__doc__:
                 doc = info.parse_docstring(
                     item[1].__doc__)["short_description"]
@@ -436,6 +548,9 @@ def _add_command_parsers(categories, subparsers):
         category_subparsers = parser.add_subparsers(dest="action")
 
         for method_name, method in _methods_of(command_object):
+            if method is None:
+                continue
+            method_name = method_name.replace("_", "-")
             descr = _compose_action_description(method)
             parser = category_subparsers.add_parser(
                 getattr(method, "alias", method_name),
@@ -486,51 +601,13 @@ def run(argv, categories):
                                       help=help_msg))
 
     try:
-        CONF(argv[1:], project="rally", version=version.version_string(),
-             default_config_files=find_config_files(CONFIG_SEARCH_PATHS))
-        logging.setup("rally")
-        if not CONF.get("log_config_append"):
-            # The below two lines are to disable noise from request module. The
-            # standard way should be we make such lots of settings on the root
-            # rally. However current oslo codes doesn't support such interface.
-            # So I choose to use a 'hacking' way to avoid INFO logs from
-            # request module where user didn't give specific log configuration.
-            # And we could remove this hacking after oslo.log has such
-            # interface.
-            LOG.debug("INFO logs from urllib3 and requests module are hide.")
-            requests_log = logging.getLogger("requests").logger
-            requests_log.setLevel(logging.WARNING)
-            urllib3_log = logging.getLogger("urllib3").logger
-            urllib3_log.setLevel(logging.WARNING)
-
-            LOG.debug("urllib3 insecure warnings are hidden.")
-            for warning in ("InsecurePlatformWarning",
-                            "SNIMissingWarning",
-                            "InsecureRequestWarning"):
-                warning_cls = getattr(urllib3.exceptions, warning, None)
-                if warning_cls is not None:
-                    urllib3.disable_warnings(warning_cls)
-
-            # NOTE(wtakase): This is for suppressing boto error logging.
-            LOG.debug("ERROR log from boto module is hide.")
-            boto_log = logging.getLogger("boto").logger
-            boto_log.setLevel(logging.CRITICAL)
-
-    except cfg.ConfigFilesNotFoundError:
-        cfgfile = CONF.config_file[-1] if CONF.config_file else None
-        if cfgfile and not os.access(cfgfile, os.R_OK):
-            st = os.stat(cfgfile)
-            print(_("Could not read %s. Re-running with sudo") % cfgfile)
-            try:
-                os.execvp("sudo", ["sudo", "-u", "#%s" % st.st_uid] + sys.argv)
-            except Exception:
-                print(_("sudo failed, continuing as if nothing happened"))
-
-        print(_("Please re-run %s as root.") % argv[0])
+        rapi = api.API(config_args=argv[1:], skip_db_check=True)
+    except exceptions.RallyException as e:
+        print(e)
         return(2)
 
     if CONF.category.name == "version":
-        print(version.version_string())
+        print(CONF.version)
         return(0)
 
     if CONF.category.name == "bash-completion":
@@ -540,6 +617,8 @@ def run(argv, categories):
     fn = CONF.category.action_fn
     fn_args = [encodeutils.safe_decode(arg)
                for arg in CONF.category.action_args]
+    # api instance always is the first argument
+    fn_args.insert(0, rapi)
     fn_kwargs = {}
     for k in CONF.category.action_kwargs:
         v = getattr(CONF.category, "action_kwarg_" + k)
@@ -568,11 +647,12 @@ def run(argv, categories):
         return(1)
 
     try:
-        for path in CONF.plugin_paths or []:
-            discover.load_plugins(path)
-
         validate_deprecated_args(argv, fn)
 
+        # skip db check for db and plugin commands
+        if CONF.category.name not in ("db", "plugin"):
+            rapi.check_db_revision()
+
         if getattr(fn, "_suppress_warnings", False):
             with warnings.catch_warnings():
                 warnings.simplefilter("ignore")
@@ -581,8 +661,8 @@ def run(argv, categories):
             ret = fn(*fn_args, **fn_kwargs)
         return(ret)
 
-    except (IOError, TypeError, ValueError, exceptions.DeploymentNotFound,
-            exceptions.TaskNotFound, jsonschema.ValidationError) as e:
+    except (IOError, TypeError, ValueError,
+            exceptions.RallyException, jsonschema.ValidationError) as e:
         if logging.is_debug():
             LOG.exception(e)
         print(e)
@@ -655,7 +735,9 @@ complete -o filenames -F _rally rally
     completion = []
     for category, cmds in main.categories.items():
         for name, command in _methods_of(cmds):
-            command_name = getattr(command, "alias", name)
+            if name is None:
+                continue
+            command_name = getattr(command, "alias", name.replace("_", "-"))
             args_list = []
             for arg in getattr(command, "args", []):
                 if getattr(command, "deprecated_args", []):
