@@ -25,13 +25,13 @@ import sys
 import jsonschema
 from keystoneclient import exceptions as keystone_exceptions
 from six.moves.urllib import parse
-import yaml
 
 from rally.cli import cliutils
 from rally.cli import envutils
 from rally.common import fileutils
 from rally.common.i18n import _
 from rally.common import utils
+from rally.common import yamlutils as yaml
 from rally import exceptions
 from rally import plugins
 
@@ -53,14 +53,14 @@ class DeploymentCommands(object):
         """Create new deployment.
 
         This command will create a new deployment record in rally
-        database. In the case of ExistingCloud deployment engine it
+        database. In the case of ExistingCloud deployment engine, it
         will use the cloud represented in the configuration. If the
         cloud doesn't exist, Rally can deploy a new one for you with
         Devstack or Fuel. Different deployment engines exist for these
         cases.
 
-        If you use the ExistingCloud deployment engine you can pass
-        a deployment config by environment variables with ``--fromenv``:
+        If you use the ExistingCloud deployment engine, you can pass
+        the deployment config by environment variables with ``--fromenv``:
 
             OS_USERNAME
             OS_PASSWORD
@@ -202,8 +202,9 @@ class DeploymentCommands(object):
         table_rows = []
 
         deployment = api.deployment.get(deployment)
-        users = deployment["users"]
-        admin = deployment["admin"]
+        creds = deployment.get_credentials_for("openstack")
+        users = creds["users"]
+        admin = creds["admin"]
         credentials = users + [admin] if admin else users
 
         for ep in credentials:
@@ -233,7 +234,8 @@ class DeploymentCommands(object):
         try:
             services = api.deployment.check(deployment)
         except keystone_exceptions.ConnectionRefused:
-            print(_("Unable to connect %s.") % deployment["admin"]["auth_url"])
+            admin = deployment.get_credentials_for("openstack")["admin"]
+            print(_("Unable to connect %s.") % admin["auth_url"])
             return(1)
 
         except exceptions.InvalidArgumentsException:
@@ -305,9 +307,10 @@ class DeploymentCommands(object):
 
             fileutils.update_globals_file("RALLY_DEPLOYMENT",
                                           deployment["uuid"])
+
+            creds = deployment.get_credentials_for("openstack")
             self._update_openrc_deployment_file(
-                deployment["uuid"],
-                deployment["admin"] or deployment["users"][0])
+                deployment["uuid"], creds["admin"] or creds["users"][0])
             print("~/.rally/openrc was updated\n\nHINTS:\n"
                   "\n* To use standard OpenStack clients, set up your env by "
                   "running:\n\tsource ~/.rally/openrc\n"
