@@ -26,7 +26,6 @@ import jsonschema
 from oslo_utils import uuidutils
 import six
 from six.moves.urllib import parse as urlparse
-import yaml
 
 from rally.cli import cliutils
 from rally.cli import envutils
@@ -36,6 +35,7 @@ from rally.common.io import junit
 from rally.common import logging
 from rally.common import utils as rutils
 from rally.common import version
+from rally.common import yamlutils as yaml
 from rally import consts
 from rally import exceptions
 from rally import plugins
@@ -80,7 +80,7 @@ class TaskCommands(object):
             try:
                 kw = args and yaml.safe_load(args)
                 kw = {} if kw is None else kw
-            except yaml.parser.ParserError as e:
+            except yaml.ParserError as e:
                 print_invalid_header(src_name, args)
                 print(_("%(source)s has to be YAML or JSON. Details:"
                         "\n\n%(err)s\n")
@@ -118,7 +118,7 @@ class TaskCommands(object):
                       file=sys.stderr)
                 raise FailedToLoadTask()
 
-            print(_("Input task is:\n%s\n") % rendered_task)
+            print(_("Task is:\n%s\n") % rendered_task)
             try:
                 parsed_task = yaml.safe_load(rendered_task)
 
@@ -137,9 +137,10 @@ class TaskCommands(object):
             input_task = self._load_task(api, task, task_args, task_args_file)
         except Exception as err:
             if task_instance:
-                task_instance.set_failed(err.__class__.__name__,
-                                         str(err),
-                                         json.dumps(traceback.format_exc()))
+                task_instance.set_validation_failed({
+                    "etype": err.__class__.__name__,
+                    "msg": str(err),
+                    "trace": json.dumps(traceback.format_exc())})
             raise
         api.task.validate(deployment, input_task, task_instance)
         print(_("Task config is valid :)"))
@@ -235,9 +236,9 @@ class TaskCommands(object):
                                      for it fails
         """
 
-        task_instance = api.task.create(deployment, tag)
-
         try:
+            task_instance = api.task.create(deployment, tag)
+
             print("Running Rally version", version.version_string())
             input_task = self._load_and_validate_task(
                 api, task, task_args, task_args_file, deployment,
@@ -258,10 +259,14 @@ class TaskCommands(object):
                            abort_on_sla_failure=abort_on_sla_failure)
             self.detailed(api, task_id=task_instance["uuid"])
 
+        except exceptions.DeploymentNotFinishedStatus as e:
+            print(_("Cannot start a task on unfinished deployment: %s") % e)
+            return 1
         except (exceptions.InvalidTaskException, FailedToLoadTask) as e:
-            task_instance.set_failed(type(e).__name__,
-                                     str(e),
-                                     json.dumps(traceback.format_exc()))
+            task_instance.set_validation_failed({
+                "etype": type(e).__name__,
+                "msg": str(e),
+                "trace": json.dumps(traceback.format_exc())})
             print(e, file=sys.stderr)
             return(1)
 
@@ -324,7 +329,8 @@ class TaskCommands(object):
         print(_("Task %(task_id)s: %(status)s")
               % {"task_id": task_id, "status": task["status"]})
 
-        if task["status"] == consts.TaskStatus.FAILED:
+        if task["status"] == consts.TaskStatus.CRASHED or task["status"] == (
+                consts.TaskStatus.VALIDATION_FAILED):
             print("-" * 80)
             verification = yaml.safe_load(task["verification_log"])
             if logging.is_debug():
@@ -470,12 +476,13 @@ class TaskCommands(object):
             print(_("Task status is %s. Results available when it is one "
                     "of %s.") % (task["status"], ", ".join(finished_statuses)))
             return 1
-
         results = [{"key": x["key"], "result": x["data"]["raw"],
                     "sla": x["data"]["sla"],
                     "hooks": x["data"].get("hooks", []),
                     "load_duration": x["data"]["load_duration"],
-                    "full_duration": x["data"]["full_duration"]}
+                    "full_duration": x["data"]["full_duration"],
+                    "created_at": x.get("created_at").strftime(
+                        "%Y-%d-%mT%H:%M:%S")}
                    for x in task.get_results()]
 
         print(json.dumps(results, sort_keys=False, indent=4))
@@ -667,7 +674,8 @@ class TaskCommands(object):
                                "hooks": x["data"].get("hooks", []),
                                "result": x["data"]["raw"],
                                "load_duration": x["data"]["load_duration"],
-                               "full_duration": x["data"]["full_duration"]},
+                               "full_duration": x["data"]["full_duration"],
+                               "created_at": x["created_at"]},
                     api.task.get(task_file_or_uuid).get_results())
             else:
                 print(_("ERROR: Invalid UUID or file name passed: %s"
