@@ -22,7 +22,6 @@ import sys
 from rally.cli import cliutils
 from rally.cli.commands import deployment
 from rally.cli.commands import plugin
-from rally.cli.commands import show
 from rally.cli.commands import task
 from rally.cli.commands import verify
 
@@ -30,7 +29,6 @@ from rally.cli.commands import verify
 categories = {
     "deployment": deployment.DeploymentCommands,
     "plugin": plugin.PluginCommands,
-    "show": show.ShowCommands,
     "task": task.TaskCommands,
     "verify": verify.VerifyCommands
 }
