@@ -24,7 +24,6 @@ from oslo_utils import timeutils
 import sqlalchemy as sa
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy import schema
-from sqlalchemy import types
 
 from rally.common.db.sqlalchemy import types as sa_types
 from rally import consts
@@ -44,7 +43,7 @@ class RallyBase(models.ModelBase):
                            onupdate=lambda: timeutils.utcnow())
 
     def save(self, session=None):
-        # NOTE(LimingWu): We can't direct import the api module. that will
+        # NOTE(LimingWu): We can't direct import the api module. That will
         # result in the cyclic reference import since the api has imported
         # this module.
         from rally.common.db.sqlalchemy import api as sa_api
@@ -83,7 +82,8 @@ class Deployment(BASE, RallyBase):
         nullable=False,
     )
 
-    credentials = sa.Column(types.PickleType, default=[], nullable=False)
+    credentials = sa.Column(
+        sa_types.MutableJSONEncodedDict, default={}, nullable=False)
 
     status = sa.Column(
         sa.Enum(*consts.DeployStatus, name="enum_deploy_status"),
@@ -99,24 +99,6 @@ class Deployment(BASE, RallyBase):
         foreign_keys=parent_uuid,
     )
 
-    # TODO(rpromyshlennikov): remove admin after credentials refactoring
-    @property
-    def admin(self):
-        return self.credentials[0][1]["admin"]
-
-    @admin.setter
-    def admin(self, value):
-        pass
-
-    # TODO(rpromyshlennikov): remove users after credentials refactoring
-    @property
-    def users(self):
-        return self.credentials[0][1]["users"]
-
-    @users.setter
-    def users(self, value):
-        pass
-
 
 class Resource(BASE, RallyBase):
     """Represent a resource of a deployment."""
@@ -187,11 +169,7 @@ class Task(BASE, RallyBase):
     validation_duration = sa.Column(sa.Float)
     task_duration = sa.Column(sa.Float)
     pass_sla = sa.Column(sa.Boolean)
-
-    status = sa.Column(sa.Enum(*list(consts.TaskStatus),
-                       name="enum_tasks_status"),
-                       default=consts.TaskStatus.INIT,
-                       nullable=False)
+    status = sa.Column(sa.String(36), default=consts.TaskStatus.INIT)
 
 
 class Subtask(BASE, RallyBase):
@@ -229,11 +207,7 @@ class Subtask(BASE, RallyBase):
     run_in_parallel = sa.Column(sa.Boolean, default=False, nullable=False)
     duration = sa.Column(sa.Float)
     pass_sla = sa.Column(sa.Boolean)
-
-    status = sa.Column(sa.Enum(*list(consts.SubtaskStatus),
-                       name="enum_subtasks_status"),
-                       default=consts.SubtaskStatus.RUNNING,
-                       nullable=False)
+    status = sa.Column(sa.String(36), default=consts.SubtaskStatus.RUNNING)
 
 
 class Workload(BASE, RallyBase):
@@ -475,7 +449,7 @@ def drop_all_objects(engine):
 
 
 def drop_db():
-    # NOTE(LimingWu): We can't direct import the api module. that will
+    # NOTE(LimingWu): We can't direct import the api module. That will
     # result in the cyclic reference import since the api has imported
     # this module.
     from rally.common.db.sqlalchemy import api as sa_api
