@@ -14,6 +14,7 @@
 #    under the License.
 
 import collections
+import datetime as dt
 import uuid
 
 from rally.common import db
@@ -214,6 +215,9 @@ TASK_RESULT_SCHEMA = {
         "full_duration": {
             "type": "number",
         },
+        "created_at": {
+            "type": "string"
+        }
     },
     "required": ["key", "sla", "result", "load_duration", "full_duration"],
     "additionalProperties": False
@@ -316,13 +320,25 @@ TASK_EXTENDED_RESULT_SCHEMA = {
 
 
 class Task(object):
-    """Represents a task object."""
+    """Represents a task object.
+
+    Task states graph
+
+    INIT -> VALIDATING |-> VALIDATION_FAILED
+                       |-> ABORTING -> ABORTED
+                       |-> SOFT_ABORTING -> ABORTED
+                       |-> CRASHED
+                       |-> VALIDATED |-> RUNNING |-> FINISHED
+                                                 |-> ABORTING -> ABORTED
+                                                 |-> SOFT_ABORTING -> ABORTED
+                                                 |-> CRASHED
+    """
 
     # NOTE(andreykurilin): The following stages doesn't contain check for
     #   current status of task. We should add it in the future, since "abort"
     #   cmd should work everywhere.
     # TODO(andreykurilin): allow abort for each state.
-    NOT_IMPLEMENTED_STAGES_FOR_ABORT = [consts.TaskStatus.VERIFYING,
+    NOT_IMPLEMENTED_STAGES_FOR_ABORT = [consts.TaskStatus.VALIDATING,
                                         consts.TaskStatus.INIT]
 
     def __init__(self, task=None, temporary=False, **attributes):
@@ -382,11 +398,12 @@ class Task(object):
         else:
             self._update({"status": status})
 
-    def update_verification_log(self, log):
-        self._update({"validation_result": log})
+    def set_validation_failed(self, log):
+        self._update({"status": consts.TaskStatus.VALIDATION_FAILED,
+                      "validation_result": log})
 
     def set_failed(self, etype, msg, etraceback):
-        self._update({"status": consts.TaskStatus.FAILED,
+        self._update({"status": consts.TaskStatus.CRASHED,
                       "validation_result": {
                           "etype": etype, "msg": msg, "trace": etraceback}})
 
@@ -484,7 +501,7 @@ class Task(object):
                 if serializable:
                     # NOTE(amaretskiy): convert datetime to str,
                     #     because json.dumps() does not like datetime
-                    if scenario[k]:
+                    if scenario[k] and isinstance(scenario[k], dt.datetime):
                         scenario[k] = scenario[k].strftime("%Y-%d-%mT%H:%M:%S")
                 else:
                     del scenario[k]
@@ -534,7 +551,7 @@ class Task(object):
                 {"uuid": self.task["uuid"], "status": current_status,
                  "stages": ", ".join(self.NOT_IMPLEMENTED_STAGES_FOR_ABORT)})
         elif current_status in [consts.TaskStatus.FINISHED,
-                                consts.TaskStatus.FAILED,
+                                consts.TaskStatus.CRASHED,
                                 consts.TaskStatus.ABORTED]:
             raise exceptions.RallyException(
                 _LE("Failed to abort task '%s', since it already "
