@@ -25,21 +25,24 @@ from rally.plugins.openstack.scenarios.heat import utils as heat_utils
 from rally.plugins.openstack.scenarios.ironic import utils as ironic_utils
 from rally.plugins.openstack.scenarios.magnum import utils as magnum_utils
 from rally.plugins.openstack.scenarios.manila import utils as manila_utils
+from rally.plugins.openstack.scenarios.mistral import utils as mistral_utils
 from rally.plugins.openstack.scenarios.monasca import utils as monasca_utils
 from rally.plugins.openstack.scenarios.murano import utils as murano_utils
 from rally.plugins.openstack.scenarios.nova import utils as nova_utils
 from rally.plugins.openstack.scenarios.sahara import utils as sahara_utils
 from rally.plugins.openstack.scenarios.vm import utils as vm_utils
 from rally.plugins.openstack.scenarios.watcher import utils as watcher_utils
+from rally.plugins.openstack.verification.tempest import config as tempest_conf
 from rally.plugins.openstack.wrappers import glance as glance_utils
-from rally.verification.tempest import config as tempest_conf
+from rally.task import engine
 
 
 def list_opts():
     return [
         ("DEFAULT",
          itertools.chain(logging.DEBUG_OPTS,
-                         osclients.OSCLIENTS_OPTS)),
+                         osclients.OSCLIENTS_OPTS,
+                         engine.TASK_ENGINE_OPTS)),
         ("benchmark",
          itertools.chain(cinder_utils.CINDER_BENCHMARK_OPTS,
                          ec2_utils.EC2_BENCHMARK_OPTS,
@@ -48,6 +51,7 @@ def list_opts():
                          ironic_utils.IRONIC_BENCHMARK_OPTS,
                          magnum_utils.MAGNUM_BENCHMARK_OPTS,
                          manila_utils.MANILA_BENCHMARK_OPTS,
+                         mistral_utils.MISTRAL_BENCHMARK_OPTS,
                          monasca_utils.MONASCA_BENCHMARK_OPTS,
                          murano_utils.MURANO_BENCHMARK_OPTS,
                          nova_utils.NOVA_BENCHMARK_OPTS,
