@@ -69,8 +69,8 @@ class LxcEngine(engine.Engine):
                                   "pattern": "^(\d+\.){3}\d+\/\d+$"},
             "containers_per_host": {"type": "integer"},
             "tunnel_to": {"type": "array",
-                          "elements": {"type": "string",
-                                       "pattern": "^(\d+\.){3}\d+$"}},
+                          "items": {"type": "string",
+                                    "pattern": "^(\d+\.){3}\d+$"}},
             "container_name": {"type": "string"},
             "provider": {"type": "object",
                          "properties": {"type": {"type": "string"}}},
@@ -149,7 +149,10 @@ class LxcEngine(engine.Engine):
                 container.ssh.run("/bin/sh -e", stdin=open(start_script, "rb"))
             if network:
                 network += 1
-        return {"admin": objects.Credential("", "", "", "")}
+
+        admin = objects.Credential("", "", "", "").to_dict(
+            include_permission=True)
+        return {"openstack": [{"admin": admin, "users": []}]}
 
     def cleanup(self):
         resources = self.deployment.get_resources()
