@@ -112,6 +112,11 @@ class DeploymentNameExists(RallyException):
     msg_fmt = _("Deployment name '%(deployment)s' already registered.")
 
 
+class DeploymentNotFinishedStatus(RallyException):
+    msg_fmt = _("Deployment '%(name)s' (UUID=%(uuid)s) is in"
+                " '%(status)s' status.")
+
+
 class DeploymentIsBusy(RallyException):
     msg_fmt = _("There are allocated resources for the deployment with "
                 "uuid=%(uuid)s.")
@@ -202,6 +207,10 @@ class ImageCleanUpException(CleanUpException):
     msg_fmt = _("Image Deletion Failed")
 
 
+class EncryptionTypeDeleteException(CleanUpException):
+    msg_fmt = _("EncryptionType Deletion Failed")
+
+
 class IncompatiblePythonVersion(RallyException):
     msg_fmt = _("Incompatible python version found '%(version)s', "
                 "required '%(required_version)s'")
@@ -241,10 +250,6 @@ class MultipleMatchesFound(RallyException):
         super(MultipleMatchesFound, self).__init__(**kwargs)
 
 
-class TempestConfigCreationFailure(RallyException):
-    msg_fmt = _("Unable to create Tempest config file: %(message)s")
-
-
 class SSHTimeout(RallyException):
     pass
 
