@@ -14,6 +14,7 @@
 #    under the License.
 
 import abc
+import os
 
 from oslo_config import cfg
 from six.moves.urllib import parse
@@ -285,9 +286,8 @@ class Keystone(OSClient):
         if a version override is used.
         """
         url = parse.urlparse(self.credential.auth_url)
-        # NOTE(bigjools): This assumes that non-versioned URLs have no
-        # path component at all.
-        parts = (url.scheme, url.netloc, "/", url.params, url.query,
+        path = os.path.join(*os.path.split(url.path)[:-1])
+        parts = (url.scheme, url.netloc, path, url.params, url.query,
                  url.fragment)
         return parse.urlunparse(parts)
 
@@ -388,12 +388,20 @@ class Heat(OSClient):
         """Return heat client."""
         from heatclient import client as heat
 
+        # ToDo: Remove explicit endpoint_type or interface initialization
+        #       when heatclient no longer uses it.
+        kw_args = {}
+        if self.credential.endpoint_type:
+            kw_args["endpoint_type"] = self.credential.endpoint_type
+            kw_args["interface"] = self.credential.endpoint_type
+
         client = heat.Client(
             self.choose_version(version),
             session=self.keystone.get_session()[0],
             # Remove endpoint once requirement is python-heatclient>=1.6
             endpoint=self._get_endpoint(service_type),
-            endpoint_override=self._get_endpoint(service_type))
+            endpoint_override=self._get_endpoint(service_type),
+            **kw_args)
         return client
 
 
@@ -506,18 +514,9 @@ class Zaqar(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return Zaqar client."""
         from zaqarclient.queues import client as zaqar
-        tenant_id = self.keystone.auth_ref.project_id
-        conf = {"auth_opts": {"backend": "keystone", "options": {
-            "os_username": self.credential.username,
-            "os_password": self.credential.password,
-            "os_project_name": self.credential.tenant_name,
-            "os_project_id": tenant_id,
-            "os_auth_url": self.credential.auth_url,
-            "insecure": self.credential.insecure,
-        }}}
         client = zaqar.Client(url=self._get_endpoint(),
                               version=self.choose_version(version),
-                              conf=conf)
+                              session=self.keystone.get_session()[0])
         return client
 
 
