@@ -47,19 +47,20 @@ class SynchronizedDeletion(object):
         return True
 
 
-class QuotaMixin(SynchronizedDeletion):
-
-    def id(self):
-        return self.raw_resource
-
-    def name(self):
-        return None
-
-    def delete(self):
-        self._manager().delete(self.raw_resource)
+class QuotaMixin(SynchronizedDeletion, base.ResourceManager):
+    # NOTE(andreykurilin): Quotas resources are quite complex in terms of
+    #   cleanup. First of all, they do not have name, id fields at all. There
+    #   is only one identifier - reference to Keystone Project/Tenant. Also,
+    #   we should remove them in case of existing users case... To cover both
+    #   cases we should use project name as name field (it will allow to pass
+    #   existing users case) and project id as id of resource
 
     def list(self):
-        return [self.tenant_uuid] if self.tenant_uuid else []
+        if not self.tenant_uuid:
+            return []
+        client = self._admin_required and self.admin or self.user
+        project = identity.Identity(client).get_project(self.tenant_uuid)
+        return [project]
 
 
 # MAGNUM
@@ -189,7 +190,7 @@ class NovaSecurityGroup(SynchronizedDeletion, base.ResourceManager):
 
 @base.resource("nova", "quotas", order=next(_nova_order),
                admin_required=True, tenant_resource=True)
-class NovaQuotas(QuotaMixin, base.ResourceManager):
+class NovaQuotas(QuotaMixin):
     pass
 
 
@@ -379,20 +380,85 @@ class NeutronFloatingIP(NeutronMixin):
 @base.resource("neutron", "port", order=next(_neutron_order),
                tenant_resource=True)
 class NeutronPort(NeutronMixin):
+    # NOTE(andreykurilin): port is the kind of resource that can be created
+    #   automatically. In this case it doesn't have name field which matches
+    #   our resource name templates. But we still need to identify such
+    #   resources, so let's do it by using parent resources.
+
+    ROUTER_INTERFACE_OWNERS = ("network:router_interface",
+                               "network:router_interface_distributed",
+                               "network:ha_router_replicated_interface")
+
+    ROUTER_GATEWAY_OWNER = "network:router_gateway"
+
+    def __init__(self, *args, **kwargs):
+        super(NeutronPort, self).__init__(*args, **kwargs)
+        self._cache = {}
+
+    def _get_resources(self, resource):
+        if resource not in self._cache:
+            resources = getattr(self._manager(), "list_%s" % resource)()
+            self._cache[resource] = [r for r in resources[resource]
+                                     if r["tenant_id"] == self.tenant_uuid]
+        return self._cache[resource]
+
+    def list(self):
+        ports = self._get_resources("ports")
+        for port in ports:
+            if not port.get("name"):
+                parent_name = None
+                if (port["device_owner"] in self.ROUTER_INTERFACE_OWNERS or
+                        port["device_owner"] == self.ROUTER_GATEWAY_OWNER):
+                    # first case is a port created while adding an interface to
+                    #   the subnet
+                    # second case is a port created while adding gateway for
+                    #   the network
+                    port_router = [r for r in self._get_resources("routers")
+                                   if r["id"] == port["device_id"]]
+                    if port_router:
+                        parent_name = port_router[0]["name"]
+                # NOTE(andreykurilin): in case of existing network usage,
+                #   there is no way to identify ports that was created
+                #   automatically.
+                # FIXME(andreykurilin): find the way to filter ports created
+                #   by rally
+                # elif port["device_owner"] == "network:dhcp":
+                #     # port created while attaching a floating-ip to the VM
+                #     if port.get("fixed_ips"):
+                #         port_subnets = []
+                #         for fixedip in port["fixed_ips"]:
+                #             port_subnets.extend(
+                #                 [sn for sn in self._get_resources("subnets")
+                #                  if sn["id"] == fixedip["subnet_id"]])
+                #         if port_subnets:
+                #             parent_name = port_subnets[0]["name"]
+
+                # NOTE(andreykurilin): the same case as for floating ips
+                # if not parent_name:
+                #    port_net = [net for net in self._get_resources("networks")
+                #                if net["id"] == port["network_id"]]
+                #     if port_net:
+                #         parent_name = port_net[0]["name"]
+
+                if parent_name:
+                    port["parent_name"] = parent_name
+        return ports
 
     def name(self):
-        # TODO(andreykurilin): return NoName instance only in case of "name"
-        #   field is missed
-        return base.NoName(self._resource)
+        name = self.raw_resource.get("parent_name",
+                                     self.raw_resource.get("name", ""))
+        return name or base.NoName(self._resource)
 
     def delete(self):
-        if (self.raw_resource["device_owner"] in
-            ("network:router_interface",
-             "network:router_interface_distributed",
-             "network:ha_router_replicated_interface")):
+        device_owner = self.raw_resource["device_owner"]
+        if (device_owner in self.ROUTER_INTERFACE_OWNERS or
+                device_owner == self.ROUTER_GATEWAY_OWNER):
+            if device_owner == self.ROUTER_GATEWAY_OWNER:
+                self._manager().remove_gateway_router(
+                    self.raw_resource["device_id"])
+
             self._manager().remove_interface_router(
-                self.raw_resource["device_id"],
-                {"port_id": self.raw_resource["id"]})
+                self.raw_resource["device_id"], {"port_id": self.id()})
         else:
             try:
                 self._manager().delete_port(self.id())
@@ -434,10 +500,10 @@ class NeutronSecurityGroup(NeutronMixin):
 
 @base.resource("neutron", "quota", order=next(_neutron_order),
                admin_required=True, tenant_resource=True)
-class NeutronQuota(QuotaMixin, NeutronMixin):
+class NeutronQuota(QuotaMixin):
 
     def delete(self):
-        self._manager().delete_quota(self.tenant_uuid)
+        self.admin.neutron().delete_quota(self.tenant_uuid)
 
 
 # CINDER
@@ -914,8 +980,28 @@ class KeystoneRole(KeystoneMixin, base.ResourceManager):
     pass
 
 
+# NOTE(andreykurilin): unfortunately, ec2 credentials doesn't have name
+#   and id fields. It makes impossible to identify resources belonging to
+#   particular task.
 @base.resource("keystone", "ec2", tenant_resource=True,
                order=next(_keystone_order))
 class KeystoneEc2(SynchronizedDeletion, base.ResourceManager):
+    def _manager(self):
+        return identity.Identity(self.user)
+
+    def id(self):
+        return "n/a"
+
+    def name(self):
+        return base.NoName(self._resource)
+
+    @property
+    def user_id(self):
+        return self.user.keystone.auth_ref.user_id
+
     def list(self):
-        return self._manager().list(self.raw_resource)
+        return self._manager().list_ec2credentials(self.user_id)
+
+    def delete(self):
+        self._manager().delete_ec2credential(
+            self.user_id, access=self.raw_resource.access)
