@@ -82,7 +82,7 @@ class OpenStackAPIVersions(context.Context):
                     "args": {
                         "size": 10,
                         "image": {
-                            "name": "^cirros.*uec$"
+                            "name": "^cirros.*-disk$"
                         },
                         "flavor": {
                             "name": "m1.tiny"
@@ -126,7 +126,7 @@ class OpenStackAPIVersions(context.Context):
                     "args": {
                         "size": 10,
                         "image": {
-                            "name": "^cirros.*uec$"
+                            "name": "^cirros.*-disk$"
                         },
                         "flavor": {
                             "name": "m1.tiny"
@@ -166,7 +166,10 @@ class OpenStackAPIVersions(context.Context):
                 "type": "object",
                 "properties": {
                     "version": {
-                        "anyOf": [{"type": "string"}, {"type": "number"}]
+                        "anyOf": [{"type": "string",
+                                   "description": "a string-like version."},
+                                  {"type": "number",
+                                   "description": "a number-like version."}]
                     },
                     "service_name": {
                         "type": "string"
@@ -218,9 +221,8 @@ class OpenStackAPIVersions(context.Context):
         pass
 
     @classmethod
-    def validate(cls, config, non_hidden=False):
-        super(OpenStackAPIVersions, cls).validate(config,
-                                                  non_hidden=non_hidden)
+    def validate(cls, config):
+        super(OpenStackAPIVersions, cls).validate(config)
         for client in config:
             client_cls = osclients.OSClient.get(client)
             if ("service_type" in config[client] and
