@@ -37,7 +37,12 @@ class VolumeGenerator(context.Context):
                 "minimum": 1
             },
             "type": {
-                "type": ["string", "null"]
+                "oneOf": [{"type": "string",
+                           "description": "a string-like type of volume to "
+                                          "create."},
+                          {"type": "null",
+                           "description": "Use default type for volume to "
+                                          "create."}]
             },
             "volumes_per_tenant": {
                 "type": "integer",
@@ -71,8 +76,9 @@ class VolumeGenerator(context.Context):
 
     @logging.log_task_wrapper(LOG.info, _("Exit context: `Volumes`"))
     def cleanup(self):
-        # TODO(boris-42): Delete only resources created by this context
         resource_manager.cleanup(
             names=["cinder.volumes"],
             users=self.context.get("users", []),
-            api_versions=self.context["config"].get("api_versions"))
+            api_versions=self.context["config"].get("api_versions"),
+            superclass=cinder_utils.CinderScenario,
+            task_id=self.context["task"]["uuid"])
