@@ -26,6 +26,12 @@ LOG = logging.getLogger(__name__)
 @context.configure(name="keypair", order=310)
 class Keypair(context.Context):
 
+    # NOTE(andreykurilin): "type" != "null", since we need to support backward
+    #   compatibility(previously empty dict was valid) and I hope in near
+    #   future, we will extend this context to accept keys.
+    CONFIG_SCHEMA = {"type": "object",
+                     "additionalProperties": False}
+
     def _generate_keypair(self, credential):
         nova_client = osclients.Clients(credential).nova()
         # NOTE(hughsaunders): If keypair exists, it should re-generate name.
@@ -50,6 +56,7 @@ class Keypair(context.Context):
 
     @logging.log_task_wrapper(LOG.info, _("Exit context: `keypair`"))
     def cleanup(self):
-        # TODO(boris-42): Delete only resources created by this context
         resource_manager.cleanup(names=["nova.keypairs"],
-                                 users=self.context.get("users", []))
+                                 users=self.context.get("users", []),
+                                 superclass=self.__class__,
+                                 task_id=self.context["task"]["uuid"])
