@@ -176,7 +176,7 @@ class SaharaCluster(context.Context):
 
     @logging.log_task_wrapper(LOG.info, _("Exit context: `Sahara Cluster`"))
     def cleanup(self):
-
-        # TODO(boris-42): Delete only resources created by this context
         resource_manager.cleanup(names=["sahara.clusters"],
-                                 users=self.context.get("users", []))
+                                 users=self.context.get("users", []),
+                                 superclass=utils.SaharaScenario,
+                                 task_id=self.context["task"]["uuid"])
