@@ -12,17 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+"""
+Scenarios for Ceilometer Events API.
+"""
+
 from rally import consts
-from rally import exceptions
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.scenarios.ceilometer import utils as cutils
-from rally.plugins.openstack.scenarios.keystone import utils as kutils
+from rally.plugins.openstack.scenarios.keystone import basic as kbasic
 from rally.task import validation
 
 
-"""Scenarios for Ceilometer Events API."""
-
-
 # NOTE(idegtiarov): to work with event we need to create it, there are
 # no other way except emit suitable notification from one of services,
 # for example create new user in keystone.
@@ -34,7 +34,7 @@ from rally.task import validation
                              "cleanup": ["ceilometer"]},
                     name="CeilometerEvents.create_user_and_list_events")
 class CeilometerEventsCreateUserAndListEvents(cutils.CeilometerScenario,
-                                              kutils.KeystoneScenario):
+                                              kbasic.KeystoneBasic):
 
     def run(self):
         """Create user and fetch all events.
@@ -42,12 +42,11 @@ class CeilometerEventsCreateUserAndListEvents(cutils.CeilometerScenario,
         This scenario creates user to store new event and
         fetches list of all events using GET /v2/events.
         """
-        self._user_create()
+        self.admin_keystone.create_user()
         events = self._list_events()
-        if not events:
-            raise exceptions.RallyException(
-                "Events list is empty, but it should include at least one "
-                "event about user creation")
+        msg = ("Events list is empty, but it should include at least one "
+               "event about user creation")
+        self.assertTrue(events, msg)
 
 
 @validation.required_services(consts.Service.CEILOMETER,
@@ -57,7 +56,7 @@ class CeilometerEventsCreateUserAndListEvents(cutils.CeilometerScenario,
                              "cleanup": ["ceilometer"]},
                     name="CeilometerEvents.create_user_and_list_event_types")
 class CeilometerEventsCreateUserAndListEventTypes(cutils.CeilometerScenario,
-                                                  kutils.KeystoneScenario):
+                                                  kbasic.KeystoneBasic):
 
     def run(self):
         """Create user and fetch all event types.
@@ -65,12 +64,11 @@ class CeilometerEventsCreateUserAndListEventTypes(cutils.CeilometerScenario,
         This scenario creates user to store new event and
         fetches list of all events types using GET /v2/event_types.
         """
-        self._user_create()
+        self.admin_keystone.create_user()
         event_types = self._list_event_types()
-        if not event_types:
-            raise exceptions.RallyException(
-                "Event types list is empty, but it should include at least one"
-                " type about user creation")
+        msg = ("Event types list is empty, but it should include at least one"
+               " type about user creation")
+        self.assertTrue(event_types, msg)
 
 
 @validation.required_services(consts.Service.CEILOMETER,
@@ -80,7 +78,7 @@ class CeilometerEventsCreateUserAndListEventTypes(cutils.CeilometerScenario,
                              "cleanup": ["ceilometer"]},
                     name="CeilometerEvents.create_user_and_get_event")
 class CeilometerEventsCreateUserAndGetEvent(cutils.CeilometerScenario,
-                                            kutils.KeystoneScenario):
+                                            kbasic.KeystoneBasic):
 
     def run(self):
         """Create user and gets event.
@@ -88,11 +86,9 @@ class CeilometerEventsCreateUserAndGetEvent(cutils.CeilometerScenario,
         This scenario creates user to store new event and
         fetches one event using GET /v2/events/<message_id>.
         """
-        self._user_create()
+        self.admin_keystone.create_user()
         events = self._list_events()
-        if not events:
-            raise exceptions.RallyException(
-                "Events list is empty, but it should include at least one "
-                "event about user creation")
-        event = events[0]
-        self._get_event(event_id=event.message_id)
+        msg = ("Events list is empty, but it should include at least one "
+               "event about user creation")
+        self.assertTrue(events, msg)
+        self._get_event(event_id=events[0].message_id)
