@@ -60,7 +60,7 @@ class CeilometerScenario(scenario.OpenStackScenario):
             "source": source,
             "timestamp": timestamp,
         }
-        for k, v in six.iteritems(opt_fields):
+        for k, v in opt_fields.items():
             if v:
                 sample.update({k: v})
         len_meta = len(metadata_list) if metadata_list else 0
@@ -187,6 +187,16 @@ class CeilometerScenario(scenario.OpenStackScenario):
         else:
             return self.clients("ceilometer").alarms.list()
 
+    @atomic.action_timer("ceilometer.get_alarm")
+    def _get_alarm(self, alarm_id):
+        """Get detailed information of an alarm.
+
+        :param alarm_id: Specifies id of the alarm
+        :returns: If alarm_id is existed and correct, returns
+                  detailed information of an alarm, else returns None
+        """
+        return self.clients("ceilometer").alarms.get(alarm_id)
+
     @atomic.action_timer("ceilometer.create_alarm")
     def _create_alarm(self, meter_name, threshold, kwargs):
         """Create an alarm.
