@@ -42,7 +42,14 @@ CINDER_BENCHMARK_OPTS = [
     cfg.FloatOpt("cinder_volume_delete_poll_interval",
                  default=2.0,
                  help="Interval between checks when waiting for volume"
-                      " deletion.")
+                      " deletion."),
+    cfg.FloatOpt("cinder_backup_restore_timeout",
+                 default=600.0,
+                 help="Time to wait for cinder backup to be restored."),
+    cfg.FloatOpt("cinder_backup_restore_poll_interval",
+                 default=2.0,
+                 help="Interval between checks when waiting for backup"
+                      " restoring."),
 ]
 
 CONF = cfg.CONF
@@ -369,6 +376,14 @@ class CinderScenario(scenario.OpenStackScenario):
         """
         restore = self.clients("cinder").restores.restore(backup_id, volume_id)
         restored_volume = self.clients("cinder").volumes.get(restore.volume_id)
+        backup_for_restore = self.clients("cinder").backups.get(backup_id)
+        bench_utils.wait_for(
+            backup_for_restore,
+            ready_statuses=["available"],
+            update_resource=bench_utils.get_from_manager(),
+            timeout=CONF.benchmark.cinder_backup_restore_timeout,
+            check_interval=CONF.benchmark.cinder_backup_restore_poll_interval
+        )
         return bench_utils.wait_for(
             restored_volume,
             ready_statuses=["available"],
@@ -423,6 +438,16 @@ class CinderScenario(scenario.OpenStackScenario):
             volume_type)
         return (tuple_res[0].status_code == 202)
 
+    @atomic.action_timer("cinder.set_volume_type_keys")
+    def _set_volume_type_keys(self, volume_type, metadata):
+        """Set extra specs on a volume type.
+
+        :param volume_type: The :class:`VolumeType` to set extra spec on
+        :param metadata: A dict of key/value pairs to be set
+        :returns: extra_specs if the request has been accepted
+        """
+        return volume_type.set_keys(metadata)
+
     @atomic.action_timer("cinder.transfer_create")
     def _transfer_create(self, volume_id):
         """Create a volume transfer.
@@ -463,3 +488,15 @@ class CinderScenario(scenario.OpenStackScenario):
         """
         return self.admin_clients("cinder").volume_encryption_types.list(
             search_opts)
+
+    @atomic.action_timer("cinder.delete_encryption_type")
+    def _delete_encryption_type(self, volume_type):
+        """Delete the encryption type information for the specified volume type.
+
+        :param volume_type: the volume type whose encryption type information
+                            must be deleted
+        """
+        resp = self.admin_clients("cinder").volume_encryption_types.delete(
+            volume_type)
+        if (resp[0].status_code != 202):
+            raise exceptions.EncryptionTypeDeleteException()
