@@ -22,7 +22,7 @@ from rally.task import validation
 @validation.required_openstack(admin=True)
 @validation.required_services(consts.Service.SENLIN)
 @validation.required_contexts("profiles")
-@scenario.configure(context={"cleanup": ["senlin"]},
+@scenario.configure(context={"admin_cleanup": ["senlin"]},
                     name="SenlinClusters.create_and_delete_cluster")
 class CreateAndDeleteCluster(utils.SenlinScenario):
 
@@ -45,4 +45,4 @@ class CreateAndDeleteCluster(utils.SenlinScenario):
         profile_id = self.context["tenant"]["profile"]
         cluster = self._create_cluster(profile_id, desired_capacity,
                                        min_size, max_size, timeout, metadata)
-        self._delete_cluster(cluster)
\ No newline at end of file
+        self._delete_cluster(cluster)
