@@ -36,25 +36,30 @@ LOG = logging.getLogger(__name__)
 
 @types.convert(image={"type": "glance_image"},
                flavor={"type": "nova_flavor"})
-@validation.image_valid_on_flavor("flavor", "image")
+@validation.image_valid_on_flavor("flavor", "image", fail_on_404_image=False)
 @validation.valid_command("command")
 @validation.number("port", minval=1, maxval=65535, nullable=True,
                    integer_only=True)
 @validation.external_network_exists("floating_network")
+@validation.required_param_or_context(arg_name="image",
+                                      ctx_name="image_command_customizer")
 @validation.required_services(consts.Service.NOVA, consts.Service.CINDER)
 @validation.required_openstack(users=True)
 @scenario.configure(context={"cleanup": ["nova", "cinder"],
-                             "keypair": {}, "allow_ssh": {}},
+                             "keypair": {}, "allow_ssh": None},
                     name="VMTasks.boot_runcommand_delete")
 class BootRuncommandDelete(vm_utils.VMScenario):
 
-    def run(self, image, flavor, username, password=None, command=None,
+    def run(self, flavor, username, password=None,
+            image=None,
+            command=None,
             volume_args=None, floating_network=None, port=22,
             use_floating_ip=True, force_delete=False, wait_for_ping=True,
             max_log_length=None, **kwargs):
         """Boot a server, run script specified in command and delete server.
 
-        :param image: glance image name to use for the vm
+        :param image: glance image name to use for the vm. Optional
+            in case of specified "image_command_customizer" context
         :param flavor: VM flavor name
         :param username: ssh username on server, str
         :param password: Password on SSH authentication
@@ -75,8 +80,9 @@ class BootRuncommandDelete(vm_utils.VMScenario):
             `local_path' is given). Uploading an interpreter is possible
             but requires that `remote_path' and `interpreter' path do match.
 
+            Examples:
 
-            Examples::
+              .. code-block:: python
 
                 # Run a `local_script.pl' file sending it to a remote
                 # Perl interpreter
@@ -137,11 +143,13 @@ class BootRuncommandDelete(vm_utils.VMScenario):
                   data: dict, JSON output from the script
                   errors: str, raw data from the script's stderr stream
         """
-
         if volume_args:
             volume = self._create_volume(volume_args["size"], imageRef=None)
             kwargs["block_device_mapping"] = {"vdrally": "%s:::1" % volume.id}
 
+        if not image:
+            image = self.context["tenant"]["custom_image"]["id"]
+
         server, fip = self._boot_server_with_fip(
             image, flavor, use_floating_ip=use_floating_ip,
             floating_network=floating_network,
@@ -153,19 +161,23 @@ class BootRuncommandDelete(vm_utils.VMScenario):
 
             code, out, err = self._run_command(
                 fip["ip"], port, username, password, command=command)
+            text_area_output = ["StdErr: %s" % (err or "(none)"),
+                                "StdOut:"]
             if code:
                 raise exceptions.ScriptError(
                     "Error running command %(command)s. "
                     "Error %(code)s: %(error)s" % {
                         "command": command, "code": code, "error": err})
-
+            # Let's try to load output data
             try:
                 data = json.loads(out)
-            except ValueError as e:
-                raise exceptions.ScriptError(
-                    "Command %(command)s has not output valid JSON: %(error)s."
-                    " Output: %(output)s" % {
-                        "command": command, "error": str(e), "output": out})
+                # 'echo 42' produces very json-compatible result
+                #  - check it here
+                if not isinstance(data, dict):
+                    raise ValueError
+            except ValueError:
+                # It's not a JSON, probably it's 'script_inline' result
+                data = []
         except (exceptions.TimeoutException,
                 exceptions.SSHTimeout):
             console_logs = self._get_server_console_output(server,
@@ -177,62 +189,16 @@ class BootRuncommandDelete(vm_utils.VMScenario):
             self._delete_server_with_fip(server, fip,
                                          force_delete=force_delete)
 
-        if type(data) != dict:
-            raise exceptions.ScriptError(
-                "Command has returned data in unexpected format.\n"
-                "Expected format: {"
-                "\"additive\": [{chart data}, {chart data}, ...], "
-                "\"complete\": [{chart data}, {chart data}, ...]}\n"
-                "Actual data: %s" % data)
-
-        if set(data) - {"additive", "complete"}:
-            LOG.warning(
-                "Deprecated since Rally release 0.4.1: command has "
-                "returned data in format {\"key\": <value>, ...}\n"
-                "Expected format: {"
-                "\"additive\": [{chart data}, {chart data}, ...], "
-                "\"complete\": [{chart data}, {chart data}, ...]}")
-            output = None
-            try:
-                output = [[str(k), float(v)] for k, v in data.items()]
-            except (TypeError, ValueError):
-                raise exceptions.ScriptError(
-                    "Command has returned data in unexpected format.\n"
-                    "Expected format: {key1: <number>, "
-                    "key2: <number>, ...}.\n"
-                    "Actual data: %s" % data)
-            if output:
-                self.add_output(additive={"title": "Command output",
-                                          "chart_plugin": "Lines",
-                                          "data": output})
-        else:
+        if isinstance(data, dict) and set(data) == {"additive", "complete"}:
             for chart_type, charts in data.items():
                 for chart in charts:
                     self.add_output(**{chart_type: chart})
-
-
-@types.convert(image={"type": "glance_image"},
-               flavor={"type": "nova_flavor"})
-@validation.number("port", minval=1, maxval=65535, nullable=True,
-                   integer_only=True)
-@validation.valid_command("command")
-@validation.external_network_exists("floating_network")
-@validation.required_services(consts.Service.NOVA, consts.Service.CINDER)
-@validation.required_openstack(users=True)
-@validation.required_contexts("image_command_customizer")
-@scenario.configure(context={"cleanup": ["nova", "cinder"],
-                             "keypair": {}, "allow_ssh": {}},
-                    name="VMTasks.boot_runcommand_delete_custom_image")
-class BootRuncommandDeleteCustomImage(vm_utils.VMScenario):
-
-    def run(self, **kwargs):
-        """Boot a server from a custom image, run a command that outputs JSON.
-
-        Example Script in rally-jobs/extra/install_benchmark.sh
-        """
-        boot_runcommand_delete = BootRuncommandDelete(self.context)
-        return boot_runcommand_delete.run(
-            image=self.context["tenant"]["custom_image"]["id"], **kwargs)
+        else:
+            # it's a dict with several unknown lines
+            text_area_output.extend(out.split("\n"))
+            self.add_output(complete={"title": "Script Output",
+                                      "chart_plugin": "TextArea",
+                                      "data": text_area_output})
 
 
 @scenario.configure(context={"cleanup": ["nova", "heat"],
@@ -245,11 +211,12 @@ class RuncommandHeat(vm_utils.VMScenario):
 
          Workload can be either file or resource:
 
-         .. code-block: json
+           .. code-block:: json
 
              {"file": "/path/to/file.sh"}
              {"resource": ["package.module", "workload.py"]}
 
+
          Also it should contain "username" key.
 
          Given file will be uploaded to `gate_node` and started. This script
@@ -305,4 +272,142 @@ class RuncommandHeat(vm_utils.VMScenario):
                       "data": {
                           "cols": ["key", "value"],
                           "rows": rows}}
-        )
\ No newline at end of file
+        )
+
+BASH_DD_LOAD_TEST = """
+#!/bin/sh
+# Load server and output JSON results ready to be processed
+# by Rally scenario
+
+for ex in awk top grep free tr df dc dd gzip
+do
+    if ! type ${ex} >/dev/null
+    then
+        echo "Executable is required by script but not available\
+         on a server: ${ex}" >&2
+        return 1
+    fi
+done
+
+get_used_cpu_percent() {
+    echo 100\
+     $(top -b -n 1 | grep -i CPU | head -n 1 | awk '{print $8}' | tr -d %)\
+      - p | dc
+}
+
+get_used_ram_percent() {
+    local total=$(free | grep Mem: | awk '{print $2}')
+    local used=$(free | grep -- -/+\ buffers | awk '{print $3}')
+    echo ${used} 100 \* ${total} / p | dc
+}
+
+get_used_disk_percent() {
+    df -P / | grep -v Filesystem | awk '{print $5}' | tr -d %
+}
+
+get_seconds() {
+    (time -p ${1}) 2>&1 | awk '/real/{print $2}'
+}
+
+complete_load() {
+    local script_file=${LOAD_SCRIPT_FILE:-/tmp/load.sh}
+    local stop_file=${LOAD_STOP_FILE:-/tmp/load.stop}
+    local processes_num=${LOAD_PROCESSES_COUNT:-20}
+    local size=${LOAD_SIZE_MB:-5}
+
+    cat << EOF > ${script_file}
+until test -e ${stop_file}
+do dd if=/dev/urandom bs=1M count=${size} 2>/dev/null | gzip >/dev/null ; done
+EOF
+
+    local sep
+    local cpu
+    local ram
+    local dis
+    rm -f ${stop_file}
+    for i in $(seq ${processes_num})
+    do
+        i=$((i-1))
+        sh ${script_file} &
+        cpu="${cpu}${sep}[${i}, $(get_used_cpu_percent)]"
+        ram="${ram}${sep}[${i}, $(get_used_ram_percent)]"
+        dis="${dis}${sep}[${i}, $(get_used_disk_percent)]"
+        sep=", "
+    done
+    > ${stop_file}
+    cat << EOF
+    {
+      "title": "Generate load by spawning processes",
+      "description": "Each process runs gzip for ${size}M urandom data\
+       in a loop",
+      "chart_plugin": "Lines",
+      "axis_label": "Number of processes",
+      "label": "Usage, %",
+      "data": [
+        ["CPU", [${cpu}]],
+        ["Memory", [${ram}]],
+        ["Disk", [${dis}]]]
+    }
+EOF
+}
+
+additive_dd() {
+    local c=${1:-50} # Megabytes
+    local file=/tmp/dd_test.img
+    local write=$(get_seconds "dd if=/dev/urandom of=${file} bs=1M count=${c}")
+    local read=$(get_seconds "dd if=${file} of=/dev/null bs=1M count=${c}")
+    local gzip=$(get_seconds "gzip ${file}")
+    rm ${file}.gz
+    cat << EOF
+    {
+      "title": "Write, read and gzip file",
+      "description": "Using file '${file}', size ${c}Mb.",
+      "chart_plugin": "StackedArea",
+      "data": [
+        ["write_${c}M", ${write}],
+        ["read_${c}M", ${read}],
+        ["gzip_${c}M", ${gzip}]]
+    },
+    {
+      "title": "Statistics for write/read/gzip",
+      "chart_plugin": "StatsTable",
+      "data": [
+        ["write_${c}M", ${write}],
+        ["read_${c}M", ${read}],
+        ["gzip_${c}M", ${gzip}]]
+    }
+
+EOF
+}
+
+cat << EOF
+{
+  "additive": [$(additive_dd)],
+  "complete": [$(complete_load)]
+}
+EOF
+"""
+
+
+@types.convert(image={"type": "glance_image"},
+               flavor={"type": "nova_flavor"})
+@validation.image_valid_on_flavor("flavor", "image")
+@validation.valid_command("command")
+@validation.number("port", minval=1, maxval=65535, nullable=True,
+                   integer_only=True)
+@validation.external_network_exists("floating_network")
+@validation.required_services(consts.Service.NOVA, consts.Service.CINDER)
+@validation.required_openstack(users=True)
+@scenario.configure(context={"cleanup": ["nova", "cinder"],
+                             "keypair": {}, "allow_ssh": None},
+                    name="VMTasks.dd_load_test")
+class DDLoadTest(BootRuncommandDelete):
+
+    def run(self, command, **kwargs):
+        """Boot a server from a custom image, run a command that outputs JSON.
+
+        Example Script in rally-jobs/extra/install_benchmark.sh
+        :param command: default parameter from scenario
+        """
+        command["script_inline"] = BASH_DD_LOAD_TEST
+        return super(DDLoadTest, self).run(command=command, **kwargs)
