@@ -36,6 +36,12 @@ class KeystoneWrapper(object):
     def __init__(self, client):
         self.client = client
 
+        LOG.warning(
+            "Class %s is deprecated since Rally 0.8.0 and will be removed "
+            "soon. Use "
+            "rally.plugins.openstack.services.identity.identity.Identity "
+            "instead." % self.__class__)
+
     def __getattr__(self, attr_name):
         return getattr(self.client, attr_name)
 
@@ -87,6 +93,13 @@ class KeystoneWrapper(object):
         """List all services."""
         return map(KeystoneWrapper._wrap_service, self.client.services.list())
 
+    def create_role(self, name, **kwargs):
+        """create a role.
+
+        :param name: name of role
+        :param kwargs: Optional additional arguments for roles creation
+        """
+
     def delete_role(self, role_id):
         """Deletes role."""
         self.client.roles.delete(role_id)
@@ -122,6 +135,10 @@ class KeystoneV2Wrapper(KeystoneWrapper):
     def _wrap_v2_tenant(tenant):
         return Project(id=tenant.id, name=tenant.name, domain_id="default")
 
+    @staticmethod
+    def _wrap_v2_role(role):
+        return Role(id=role.id, name=role.name)
+
     @staticmethod
     def _wrap_v2_user(user):
         return User(id=user.id, name=user.name,
@@ -153,6 +170,10 @@ class KeystoneV2Wrapper(KeystoneWrapper):
         return map(KeystoneV2Wrapper._wrap_v2_tenant,
                    self.client.tenants.list())
 
+    def create_role(self, name):
+        role = self.client.roles.create(name)
+        return KeystoneV2Wrapper._wrap_v2_role(role)
+
     def add_role(self, role_id, user_id, project_id):
         self.client.roles.add_user_role(user_id, role_id, tenant=project_id)
 
@@ -178,6 +199,10 @@ class KeystoneV3Wrapper(KeystoneWrapper):
         return Project(id=project.id, name=project.name,
                        domain_id=project.domain_id)
 
+    @staticmethod
+    def _wrap_v3_role(role):
+        return Role(id=role.id, name=role.name)
+
     @staticmethod
     def _wrap_v3_user(user):
         # When user has default_project_id that is None user.default_project_id
@@ -221,6 +246,10 @@ class KeystoneV3Wrapper(KeystoneWrapper):
         return map(KeystoneV3Wrapper._wrap_v3_project,
                    self.client.projects.list())
 
+    def create_role(self, name, domain, **kwargs):
+        role = self.client.roles.create(name, domain=domain, **kwargs)
+        return KeystoneV3Wrapper._wrap_v3_role(role)
+
     def add_role(self, role_id, user_id, project_id):
         self.client.roles.grant(role_id, user=user_id, project=project_id)
 
@@ -230,6 +259,10 @@ class KeystoneV3Wrapper(KeystoneWrapper):
 
 def wrap(client):
     """Returns keystone wrapper based on keystone client version."""
+    LOG.warning("Method wrap from %s and whole Keystone wrappers are "
+                "deprecated since Rally 0.8.0 and will be removed soon. Use "
+                "rally.plugins.openstack.services.identity.identity.Identity "
+                "instead." % __file__)
 
     if client.version == "v2.0":
         return KeystoneV2Wrapper(client)
