@@ -18,6 +18,8 @@ import copy
 import operator
 import re
 
+import six
+
 from rally.common.plugin import plugin
 from rally import exceptions
 from rally import osclients
@@ -52,9 +54,6 @@ def _get_preprocessor_loader(plugin_name):
 def convert(**kwargs):
     """Decorator to define resource transformation(s) on scenario parameters.
 
-    This will eventually replace set(). For the time being, set()
-    should be preferred.
-
     The ``kwargs`` passed as arguments are used to map a key in the
     scenario config to the resource type plugin used to perform a
     transformation on the value of the key. For instance:
@@ -102,6 +101,7 @@ def preprocess(name, context, args):
 
 
 @plugin.base()
+@six.add_metaclass(abc.ABCMeta)
 class ResourceType(plugin.Plugin):
 
     @classmethod
