@@ -21,10 +21,10 @@ import re
 from glanceclient import exc as glance_exc
 from novaclient import exceptions as nova_exc
 import six
-import yaml
 
 from rally.common.i18n import _
 from rally.common import objects
+from rally.common import yamlutils as yaml
 from rally import consts
 from rally import exceptions
 from rally import osclients
@@ -171,7 +171,7 @@ def file_exists(config, clients, deployment, param_name, mode=os.R_OK,
 def check_command_dict(command):
     """Check command-specifying dict `command', raise ValueError on error."""
 
-    if type(command) != dict:
+    if not isinstance(command, dict):
         raise ValueError("Command must be a dictionary")
 
     # NOTE(pboldin): Here we check for the values not for presence of the keys
@@ -249,6 +249,7 @@ def _get_validated_image(config, clients, param_name):
     if not image_args:
         msg = _("Parameter %s is not specified.") % param_name
         return (ValidationResult(False, msg), None)
+
     if "image_name" in image_context:
         # NOTE(rvasilets) check string is "exactly equal to" a regex
         # or image name from context equal to image name from args
@@ -338,7 +339,9 @@ def image_exists(config, clients, deployment, param_name, nullable=False):
     image_value = config.get("args", {}).get(param_name)
     if not image_value and nullable:
         return ValidationResult(True)
-    return _get_validated_image(config, clients, param_name)[0]
+    res = _get_validated_image(config, clients, param_name)
+    if res:
+        return res[0]
 
 
 @validator
@@ -353,7 +356,8 @@ def flavor_exists(config, clients, deployment, param_name):
 
 @validator
 def image_valid_on_flavor(config, clients, deployment, flavor_name,
-                          image_name, validate_disk=True):
+                          image_name, validate_disk=True,
+                          fail_on_404_image=True):
     """Returns validator for image could be used for current flavor
 
     :param flavor_name: defines which variable should be used
@@ -364,13 +368,18 @@ def image_valid_on_flavor(config, clients, deployment, flavor_name,
                           Should be True if instance is booted from image.
                           Should be False if instance is booted from volume.
                           Default value is True.
-
+    :param fail_on_404_image: flag what indicate whether to validate image
+                              or not.
     """
     valid_result, flavor = _get_validated_flavor(config, clients, flavor_name)
     if not valid_result.is_valid:
         return valid_result
 
     valid_result, image = _get_validated_image(config, clients, image_name)
+
+    if not image and not fail_on_404_image:
+        return ValidationResult(True)
+
     if not valid_result.is_valid:
         return valid_result
 
@@ -451,8 +460,9 @@ def required_services(config, clients, deployment, *required_services):
     available_services = list(clients.services().values())
 
     if consts.Service.NOVA_NET in required_services:
+        creds = deployment.get_credentials_for("openstack")
         nova = osclients.Clients(
-            objects.Credential(**deployment["admin"])).nova()
+            objects.Credential(**creds["admin"])).nova()
         for service in nova.services.list():
             if (service.binary == consts.Service.NOVA_NET and
                     service.status == "enabled"):
@@ -496,9 +506,9 @@ def required_cinder_services(config, clients, deployment, service_name):
 
     :param service_name: Cinder service name
     """
-
+    creds = deployment.get_credentials_for("openstack")
     admin_client = osclients.Clients(
-        objects.Credential(**deployment["admin"])).cinder()
+        objects.Credential(**creds["admin"])).cinder()
 
     for service in admin_client.services.list():
         if (service.binary == six.text_type(service_name) and
@@ -518,7 +528,8 @@ def required_clients(config, clients, deployment, *components, **kwargs):
                      admin - bool, whether to use admin clients
     """
     if kwargs.get("admin", False):
-        clients = osclients.Clients(objects.Credential(**deployment["admin"]))
+        creds = deployment.get_credentials_for("openstack")
+        clients = osclients.Clients(objects.Credential(**creds["admin"]))
 
     for client_component in components:
         try:
@@ -534,16 +545,47 @@ def required_clients(config, clients, deployment, *components, **kwargs):
 def required_contexts(config, clients, deployment, *context_names):
     """Validator checks if required benchmark contexts are specified.
 
-    :param *context_names: list of context names that should be specified
+    :param *context_names: list of strings and tuples with context names that
+        should be specified. Tuple represent 'at least one of the'.
     """
-    missing_contexts = set(context_names) - set(config.get("context", {}))
+    missing_contexts = []
+    context = config.get("context", {})
+
+    for name in context_names:
+        if isinstance(name, tuple):
+            if not set(name) & set(context):
+                # formatted string like: 'foo or bar or baz'
+                formatted_names = "'{}'".format(" or ".join(name))
+                missing_contexts.append(formatted_names)
+        else:
+            if name not in context:
+                missing_contexts.append(name)
+
     if missing_contexts:
         message = (_("The following contexts are required but missing from "
                      "the benchmark configuration file: %s") %
                    ", ".join(missing_contexts))
+
         return ValidationResult(False, message)
 
 
+@validator
+def required_param_or_context(config, clients, deployment,
+                              arg_name, ctx_name):
+    """Validator checks if required image is specified.
+
+    :param arg_name: name of parameter
+    :param ctx_name: name of context
+    """
+    message = ("Parameter {} is required but not described into context {}"
+               " or arguments of scenario").format(arg_name, ctx_name)
+    if ctx_name in config.get("context", {}):
+        return ValidationResult(True)
+    if arg_name in config.get("args", {}):
+        return ValidationResult(True)
+    return ValidationResult(False, message)
+
+
 @validator
 def required_openstack(config, clients, deployment, admin=False, users=False):
     """Validator that requires OpenStack admin or (and) users.
@@ -562,16 +604,17 @@ def required_openstack(config, clients, deployment, admin=False, users=False):
         return ValidationResult(
             False, _("You should specify admin=True or users=True or both."))
 
-    if deployment["admin"] and deployment["users"]:
+    creds = deployment.get_credentials_for("openstack")
+    if creds["admin"] and creds["users"]:
         return ValidationResult(True)
 
-    if deployment["admin"]:
+    if creds["admin"]:
         if users and not config.get("context", {}).get("users"):
             return ValidationResult(False,
                                     _("You should specify 'users' context"))
         return ValidationResult(True)
 
-    if deployment["users"] and admin:
+    if creds["users"] and admin:
         return ValidationResult(False, _("Admin credentials required"))
 
 
