@@ -73,9 +73,9 @@ var widgetDirective = function($compile) {
         .showControls(opts.controls)
         .clipEdge(true);
       chart.xAxis
-        .tickFormat(d3.format(opts.xformat || "d"))
-        .axisLabel(opts.xname || "")
-        .showMaxMin(false);
+        .axisLabel(opts.xname)
+        .tickFormat(opts.xformat)
+        .showMaxMin(opts.showmaxmin);
       chart.yAxis
         .orient("left")
         .tickFormat(d3.format(opts.yformat || ",.3f"));
@@ -92,9 +92,10 @@ var widgetDirective = function($compile) {
         .useInteractiveGuideline(opts.guide)
         .clipEdge(true);
       chart.xAxis
-        .tickFormat(d3.format(opts.xformat || "d"))
-        .axisLabel(opts.xname || "")
-        .showMaxMin(false);
+        .axisLabel(opts.xname)
+        .tickFormat(opts.xformat)
+        .rotateLabels(opts.xrotate)
+        .showMaxMin(opts.showmaxmin);
       chart.yAxis
         .orient("left")
         .tickFormat(d3.format(opts.yformat || ",.3f"));
@@ -138,6 +139,9 @@ var widgetDirective = function($compile) {
             "<tr>" +
             "</tbody></table>";
           var el = element.empty().append($compile(template)(scope)).children()[0]
+        } else if (attrs.widget === "TextArea") {
+          var template = "<div style='padding:0 0 5px' ng-repeat='str in data track by $index'>{{str}}</div><div style='height:10px'></div>";
+          var el = element.empty().append($compile(template)(scope)).children()[0]
         } else {
 
           var el_chart = element.addClass("chart").css({display:"block"});
@@ -184,14 +188,20 @@ var widgetDirective = function($compile) {
             }
           }
 
-          var options = {
+          var opts = {
             xname: attrs.nameX || "",
-            xformat: attrs.formatX || "d",
+            xrotate: attrs.rotateX || 0,
             yformat: attrs.formatY || ",.3f",
             controls: attrs.controls === "true",
-            guide: attrs.guide === "true"
+            guide: attrs.guide === "true",
+            showmaxmin: attrs.showmaxmin === "true"
           };
-          Chart.get_chart(attrs.widget)(el, data, options, do_after);
+          if (attrs.formatDateX) {
+            opts.xformat = function(d) { return d3.time.format(attrs.formatDateX)(new Date(d)) }
+          } else {
+            opts.xformat = d3.format(attrs.formatX || "d")
+          }
+          Chart.get_chart(attrs.widget)(el, data, opts, do_after);
         }
 
         if (attrs.nameY) {
