@@ -13,13 +13,14 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from rally.benchmark.scenarios import base
+from rally.plugins.openstack import scenario
+from rally.task import atomic
 
 
-class ScenarioPlugin(base.Scenario):
-    """Sample plugin which lists flavors."""
+@scenario.configure(name="ScenarioPlugin.list_flavors")
+class ListFlavors(scenario.OpenStackScenario):
 
-    @base.atomic_action_timer("list_flavors")
+    @atomic.action_timer("list_flavors")
     def _list_flavors(self):
         """Sample of usage clients - list flavors
 
@@ -28,13 +29,12 @@ class ScenarioPlugin(base.Scenario):
         """
         self.clients("nova").flavors.list()
 
-    @base.atomic_action_timer("list_flavors_as_admin")
+    @atomic.action_timer("list_flavors_as_admin")
     def _list_flavors_as_admin(self):
         """The same with admin clients."""
         self.admin_clients("nova").flavors.list()
 
-    @base.scenario()
-    def list_flavors(self):
+    def run(self):
         """List flavors."""
         self._list_flavors()
         self._list_flavors_as_admin()
