@@ -1,4 +1,4 @@
-#!/bin/sh -e
+#!/bin/sh -ex
 #
 # Copyright 2013: Mirantis Inc.
 # All Rights Reserved.
@@ -17,16 +17,26 @@
 
 env
 
+sudo yum remove -y python-crypto || true
+
+# NOTE(pabelanger): We run apt-get update to ensure we don't have a stale
+# package cache in the gate.
+sudo apt-get update || true
+
 sudo ./install_rally.sh --system --yes
 rally deployment list
+[ -d /etc/bash_completion.d ] && cat /etc/bash_completion.d/rally.bash_completion || true
 
 sudo ./install_rally.sh --system --yes
 rally deployment list
 
 sudo ./install_rally.sh --yes -d /tmp/rallytest_root/
 /tmp/rallytest_root/bin/rally deployment list
+cat /tmp/rallytest_root/etc/bash_completion.d/rally.bash_completion
 
 sudo rm -fr ~/.rally
 
 ./install_rally.sh --yes -d /tmp/rallytest_user
 /tmp/rallytest_user/bin/rally deployment list
+
+./install_rally.sh --overwrite --dbtype sqlite
