@@ -17,12 +17,11 @@ import ddt
 from keystoneclient import exceptions as keystone_exc
 import mock
 from oslo_config import cfg
-from six import moves
+import six
 import sqlalchemy.exc
 
 from rally.cli import cliutils
 from rally.cli.commands import deployment
-from rally.cli.commands import show
 from rally.cli.commands import task
 from rally.cli.commands import verify
 from rally import exceptions
@@ -40,7 +39,6 @@ class CliUtilsTestCase(test.TestCase):
         super(CliUtilsTestCase, self).setUp()
         self.categories = {
             "deployment": deployment.DeploymentCommands,
-            "show": show.ShowCommands,
             "task": task.TaskCommands,
             "verify": verify.VerifyCommands
         }
@@ -49,30 +47,109 @@ class CliUtilsTestCase(test.TestCase):
         self._unregister_opts()
         super(CliUtilsTestCase, self).tearDown()
 
-    @mock.patch("rally.cli.cliutils.os.path")
-    def test_find_config_files(self, mock_os_path):
+    def test_print_dict(self):
+        out = six.StringIO()
+        dict = {"key": "value"}
+        cliutils.print_dict(dict, out=out)
+        self.assertEqual("+----------+-------+\n"
+                         "| Property | Value |\n"
+                         "+----------+-------+\n"
+                         "| key      | value |\n"
+                         "+----------+-------+\n",
+                         out.getvalue())
 
-        mock_os_path.expanduser.return_value = "expanduser"
-        mock_os_path.abspath.return_value = "abspath"
-        mock_os_path.isfile.return_value = True
+    def test_print_dict_wrap(self):
+        out = six.StringIO()
+        dict = {"key1": "not wrapped",
+                "key2": "this will be wrapped"}
+        cliutils.print_dict(dict, wrap=16, out=out)
+        self.assertEqual("+----------+--------------+\n"
+                         "| Property | Value        |\n"
+                         "+----------+--------------+\n"
+                         "| key1     | not wrapped  |\n"
+                         "| key2     | this will be |\n"
+                         "|          | wrapped      |\n"
+                         "+----------+--------------+\n",
+                         out.getvalue())
 
-        result = cliutils.find_config_files(["path1", "path2"])
-        mock_os_path.expanduser.assert_called_once_with("path1")
-        mock_os_path.abspath.assert_called_once_with(
-            mock_os_path.expanduser.return_value)
-        mock_os_path.isfile.assert_called_once_with(
-            mock_os_path.abspath.return_value + "/rally.conf")
-        self.assertEqual([mock_os_path.abspath.return_value + "/rally.conf"],
-                         result)
+    def test_print_dict_formatters_and_fields(self):
+        out = six.StringIO()
+        dict = {"key1": "value",
+                "key2": "Value",
+                "key3": "vvv"}
+        formatters = {"foo": lambda x: x["key1"],
+                      "bar": lambda x: x["key2"]}
+        fields = ["foo", "bar"]
+        cliutils.print_dict(dict, formatters=formatters, fields=fields,
+                            out=out)
+        self.assertEqual("+----------+-------+\n"
+                         "| Property | Value |\n"
+                         "+----------+-------+\n"
+                         "| foo      | value |\n"
+                         "| bar      | Value |\n"
+                         "+----------+-------+\n",
+                         out.getvalue())
 
-        mock_os_path.isfile.return_value = False
+    def test_print_dict_header(self):
+        out = six.StringIO()
+        dict = {"key": "value"}
+        cliutils.print_dict(dict, table_label="Some Table", print_header=False,
+                            out=out)
+        self.assertEqual("+-------------+\n"
+                         "| Some Table  |\n"
+                         "+-----+-------+\n"
+                         "| key | value |\n"
+                         "+-----+-------+\n",
+                         out.getvalue())
 
-        result = cliutils.find_config_files(["path1", "path2"])
-        self.assertIsNone(result)
+    def test_print_dict_objects(self):
+        class SomeStruct(object):
+            def __init__(self, a, b):
+                self.a = a
+                self.b = b
+
+            @property
+            def c(self):
+                return self.a + self.b
+
+            def foo(self):
+                pass
+
+            @classmethod
+            def bar(cls):
+                pass
+
+            @staticmethod
+            def foobar():
+                pass
+
+        out = six.StringIO()
+        formatters = {"c": lambda x: "a + b = %s" % x.c}
+        cliutils.print_dict(SomeStruct(1, 2), formatters=formatters, out=out)
+        self.assertEqual("+----------+-----------+\n"
+                         "| Property | Value     |\n"
+                         "+----------+-----------+\n"
+                         "| a        | 1         |\n"
+                         "| b        | 2         |\n"
+                         "| c        | a + b = 3 |\n"
+                         "+----------+-----------+\n",
+                         out.getvalue())
+
+    def test_print_dict_with_spec_chars(self):
+        out = six.StringIO()
+        dict = {"key": "line1\r\nline2"}
+        cliutils.print_dict(dict, out=out)
+        self.assertEqual("+----------+-------+\n"
+                         "| Property | Value |\n"
+                         "+----------+-------+\n"
+                         "| key      | line1 |\n"
+                         "|          | line2 |\n"
+                         "+----------+-------+\n",
+                         out.getvalue())
 
     def test_make_header(self):
         h1 = cliutils.make_header("msg", size=4, symbol="=")
-        self.assertEqual(h1, "====\n msg\n====\n")
+        self.assertEqual(h1, "====\nmsg\n====\n")
 
     def test_make_table_header(self):
         actual = cliutils.make_table_header("Response Times (sec)", 40)
@@ -186,58 +263,66 @@ class CliUtilsTestCase(test.TestCase):
                                          )
         CONF.unregister_opt(category_opt)
 
-    @mock.patch("rally.cli.cliutils.CONF", config_file=None,
-                side_effect=cfg.ConfigFilesNotFoundError("config_file"))
-    def test_run_fails(self, mock_cliutils_conf):
-        ret = cliutils.run(["rally", "show", "flavors"], self.categories)
+    @mock.patch("rally.api.API",
+                side_effect=exceptions.RallyException("config_file"))
+    def test_run_fails(self, mock_rally_api_api):
+        ret = cliutils.run(["rally", "version"], self.categories)
         self.assertEqual(ret, 2)
+        mock_rally_api_api.assert_called_once_with(
+            config_args=["version"], skip_db_check=True)
 
-    def test_run_version(self):
+    @mock.patch("rally.api.API.check_db_revision")
+    def test_run_version(self, mock_api_check_db_revision):
         ret = cliutils.run(["rally", "version"], self.categories)
         self.assertEqual(ret, 0)
 
-    def test_run_bash_completion(self):
+    @mock.patch("rally.api.API.check_db_revision")
+    def test_run_bash_completion(self, mock_api_check_db_revision):
         ret = cliutils.run(["rally", "bash-completion"], self.categories)
         self.assertEqual(ret, 0)
 
-    def test_run_show(self):
-        ret = cliutils.run(["rally", "show", "keypairs"], self.categories)
-        self.assertEqual(ret, 1)
-
+    @mock.patch("rally.api.API.check_db_revision")
     @mock.patch("rally.common.db.task_get",
                 side_effect=exceptions.TaskNotFound(uuid=FAKE_TASK_UUID))
-    def test_run_task_not_found(self, mock_task_get):
+    def test_run_task_not_found(self, mock_task_get,
+                                mock_api_check_db_revision):
         ret = cliutils.run(["rally", "task", "status", "%s" % FAKE_TASK_UUID],
                            self.categories)
         self.assertTrue(mock_task_get.called)
         self.assertEqual(ret, 1)
 
+    @mock.patch("rally.api.API.check_db_revision")
     @mock.patch("rally.cli.cliutils.validate_args",
                 side_effect=cliutils.MissingArgs("missing"))
-    def test_run_show_fails(self, mock_validate_args):
-        ret = cliutils.run(["rally", "show", "keypairs"], self.categories)
+    def test_run_task_failed(self, mock_validate_args,
+                             mock_api_check_db_revision):
+        ret = cliutils.run(["rally", "task", "status", "%s" % FAKE_TASK_UUID],
+                           self.categories)
         self.assertTrue(mock_validate_args.called)
         self.assertEqual(ret, 1)
 
-    def test_run_failed_to_open_file(self):
+    @mock.patch("rally.api.API.check_db_revision")
+    def test_run_failed_to_open_file(self, mock_api_check_db_revision):
 
         class FailuresCommands(object):
 
             def failed_to_open_file(self):
                 raise IOError("No such file")
 
-        ret = cliutils.run(["rally", "failure", "failed_to_open_file"],
+        ret = cliutils.run(["rally", "failure", "failed-to-open-file"],
                            {"failure": FailuresCommands})
         self.assertEqual(1, ret)
 
-    def test_run_sqlalchmey_operational_failure(self):
+    @mock.patch("rally.api.API.check_db_revision")
+    def test_run_sqlalchmey_operational_failure(self,
+                                                mock_api_check_db_revision):
 
         class SQLAlchemyCommands(object):
 
             def operational_failure(self):
                 raise sqlalchemy.exc.OperationalError("Can't open DB file")
 
-        ret = cliutils.run(["rally", "failure", "operational_failure"],
+        ret = cliutils.run(["rally", "failure", "operational-failure"],
                            {"failure": SQLAlchemyCommands})
         self.assertEqual(1, ret)
 
@@ -376,13 +461,13 @@ class CliUtilsTestCase(test.TestCase):
                       "+---+---+")})
     @ddt.unpack
     def test_print_list(self, args, kwargs, expected):
-        out = moves.StringIO()
+        out = six.moves.StringIO()
         kwargs["out"] = out
         cliutils.print_list(*args, **kwargs)
         self.assertEqual(expected, out.getvalue().strip())
 
     def test_print_list_raises(self):
-        out = moves.StringIO()
+        out = six.moves.StringIO()
         self.assertRaisesRegexp(
             ValueError,
             "Field labels list.*has different number "
@@ -391,6 +476,54 @@ class CliUtilsTestCase(test.TestCase):
             [self.TestObj()], ["x"],
             field_labels=["x", "y"], sortby_index=None, out=out)
 
+    def test_help_for_grouped_methods(self):
+        class SomeCommand(object):
+            @cliutils.help_group("1_manage")
+            def install(self):
+                pass
+
+            @cliutils.help_group("1_manage")
+            def uninstall(self):
+                pass
+
+            @cliutils.help_group("1_manage")
+            def reinstall(self):
+                pass
+
+            @cliutils.help_group("2_launch")
+            def run(self):
+                pass
+
+            @cliutils.help_group("2_launch")
+            def rerun(self):
+                pass
+
+            @cliutils.help_group("3_results")
+            def show(self):
+                pass
+
+            @cliutils.help_group("3_results")
+            def list(self):
+                pass
+
+            def do_do_has_do_has_mesh(self):
+                pass
+
+        self.assertEqual(
+            "\n\nCommands:\n"
+            "   do-do-has-do-has-mesh   \n"
+            "\n"
+            "   install                 \n"
+            "   reinstall               \n"
+            "   uninstall               \n"
+            "\n"
+            "   rerun                   \n"
+            "   run                     \n"
+            "\n"
+            "   list                    \n"
+            "   show                    \n",
+            cliutils._compose_category_description(SomeCommand))
+
 
 class ValidateArgsTest(test.TestCase):
 
@@ -808,3 +941,13 @@ class ValidateArgsTest(test.TestCase):
         cmd_name = "test-command"
         wrapped = cliutils.alias(cmd_name)
         self.assertEqual(wrapped(alias_fn).alias, cmd_name)
+
+
+class CategoryParserTestCase(test.TestCase):
+
+    def setUp(self):
+        super(CategoryParserTestCase, self).setUp()
+        self.categoryParser = cliutils.CategoryParser()
+
+    def test_format_help(self):
+        self.assertIsNotNone(self.categoryParser.format_help())
