@@ -23,40 +23,42 @@ class SubunitParserTestCase(test.TestCase):
     fake_stream = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                                "subunit_v2.stream")
 
-    def test_parse_results_file(self):
-        result = subunit_v2.parse_results_file(self.fake_stream)
+    def test_parse_file(self):
+        result = subunit_v2.parse_file(self.fake_stream, live=True)
 
-        self.assertEqual({"skipped": 1,
+        self.assertEqual({"tests_count": 7,
+                          "tests_duration": "5.007",
+                          "skipped": 1,
                           "success": 2,
-                          "time": "5.007",
                           "failures": 3,
                           "expected_failures": 0,
-                          "tests": 7,
-                          "unexpected_success": 1}, result.total)
-        self.assertEqual(len(result.tests), result.total["tests"])
+                          "unexpected_success": 1}, result.totals)
+        self.assertEqual(len(result.tests), result.totals["tests_count"])
 
         skipped_tests = result.filter_tests("skip")
         skipped_test = "test_foo.SimpleTestCase.test_skip_something"
 
-        self.assertEqual(result.total["skipped"], len(skipped_tests))
+        self.assertEqual(result.totals["skipped"], len(skipped_tests))
         self.assertSequenceEqual([skipped_test], skipped_tests.keys())
         self.assertEqual(
             {"status": "skip", "reason": "This should be skipped.",
-             "time": "0.000", "name": skipped_test},
+             "duration": "0.000", "name": skipped_test, "tags": [],
+             "timestamp": "2015-06-03T08:46:17+0000"},
             skipped_tests[skipped_test])
 
         failed_tests = result.filter_tests("fail")
         failed_test = "test_foo.SimpleTestCaseWithBrokenSetup.test_something"
 
-        self.assertEqual(result.total["failures"], len(failed_tests))
+        self.assertEqual(result.totals["failures"], len(failed_tests))
         self.assertIn(failed_test, failed_tests)
         trace = """Traceback (most recent call last):
   File "test_foo.py", line 34, in setUp
     raise RuntimeError("broken setUp method")
 RuntimeError: broken setUp method
 """
-        self.assertEqual({"status": "fail", "traceback": trace,
-                          "time": "0.000", "name": failed_test},
+        self.assertEqual({"status": "fail", "traceback": trace, "tags": [],
+                          "duration": "0.000", "name": failed_test,
+                          "timestamp": "2015-06-03T08:46:22+0000"},
                          failed_tests[failed_test])
 
     def test_filter_results(self):
@@ -75,7 +77,7 @@ RuntimeError: broken setUp method
                           "passed_test_3": results.tests["passed_test_3"]},
                          results.filter_tests("success"))
 
-    def test_property_test(self):
+    def test__is_parsed(self):
         results = subunit_v2.SubunitV2StreamResult()
         results._tests = {
             "SkippedTestCase.test_1": {"status": "init"},
@@ -92,12 +94,12 @@ RuntimeError: broken setUp method
 
         self.assertTrue(results._is_parsed)
 
-    def test_preparse_input_args(self):
+    def test_prepare_input_args(self):
         some_mock = mock.MagicMock()
 
-        @subunit_v2.preparse_input_args
-        def some_a(self_, test_id, test_status, test_tags, file_name,
-                   file_bytes, mime_type, timestamp, charset):
+        @subunit_v2.prepare_input_args
+        def some_a(self_, test_id, test_status, timestamp, test_tags,
+                   file_name, file_bytes, worker, mime_type, charset):
             some_mock(test_id, test_tags)
 
         some_a("", "setUpClass (some_test[tag1,tag2])")
@@ -110,12 +112,12 @@ RuntimeError: broken setUp method
             "some_test[tag1,tag2]", ["tag1", "tag2"])
 
     def test_no_status_called(self):
-        self.assertEqual({"tests": 0, "time": 0, "failures": 0, "skipped": 0,
-                          "success": 0, "unexpected_success": 0,
-                          "expected_failures": 0},
-                         subunit_v2.SubunitV2StreamResult().total)
+        self.assertEqual({"tests_count": 0, "tests_duration": "%.3f" % 0,
+                          "failures": 0, "skipped": 0, "success": 0,
+                          "unexpected_success": 0, "expected_failures": 0},
+                         subunit_v2.SubunitV2StreamResult().totals)
 
-    def test_parse_results_file_with_expected_failures(self):
+    def test_parse_file_with_expected_failures(self):
         test_1 = "test_foo.SimpleTestCase.test_something_that_fails"
         test_2 = "test_foo.SimpleTestCase.test_something_that_passes"
         expected_failures = {
@@ -123,11 +125,23 @@ RuntimeError: broken setUp method
             test_2: None
         }
 
-        result = subunit_v2.parse_results_file(self.fake_stream,
-                                               expected_failures)
+        result = subunit_v2.parse_file(
+            self.fake_stream, expected_failures=expected_failures, live=True)
         tests = result.tests
 
         self.assertEqual("xfail", tests[test_1]["status"])
         self.assertEqual("Some details about why this test fails",
                          tests[test_1]["reason"])
         self.assertEqual("uxsuccess", tests[test_2]["status"])
+
+    def test_parse_file_with_skipped_tests(self):
+        test_id = "test_foo.SimpleTestCase.test_to_skip"
+        skipped_tests = {test_id: "Some details why this test skipped"}
+
+        result = subunit_v2.parse_file(
+            self.fake_stream, skipped_tests=skipped_tests, live=True)
+        tests = result.tests
+
+        self.assertEqual("skip", tests[test_id]["status"])
+        self.assertEqual("Some details why this test skipped",
+                         tests[test_id]["reason"])
