@@ -139,6 +139,12 @@ class DummyTestCase(test.TestCase):
                      "description": desc % "Complete StackedArea",
                      "label": "Yet another measurement units",
                      "title": "Complete StackedArea"},
+                    {"title": "Arbitrary Text",
+                     "chart_plugin": "TextArea",
+                     "data": ["Lorem ipsum dolor sit amet, consectetur "
+                              "adipiscing elit, sed do eiusmod tempor "
+                              "incididunt ut labore et dolore magna "
+                              "aliqua." * 2] * 4},
                     {"chart_plugin": "Pie",
                      "data": [[s, exp] for s in ("delta", "epsilon", "zeta",
                                                  "theta", "lambda", "omega")],
@@ -155,14 +161,6 @@ class DummyTestCase(test.TestCase):
 
         self.assertEqual(expected, scenario._output)
 
-    def test_dummy_dummy_with_scenario_output(self):
-        scenario = dummy.DummyWithScenarioOutput(test.get_test_context())
-        result = scenario.run()
-        self.assertEqual(result["errors"], "")
-        # Since the data is generated in random,
-        # checking for not None
-        self.assertIsNotNone(result["data"])
-
     def test_dummy_random_fail_in_atomic(self):
         scenario = dummy.DummyRandomFailInAtomic(test.get_test_context())
 
