@@ -13,6 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
+
 from boto import exception as boto_exception
 import ddt
 import mock
@@ -35,32 +37,18 @@ class SynchronizedDeletionTestCase(test.TestCase):
 
 class QuotaMixinTestCase(test.TestCase):
 
-    def test_id(self):
-        quota = resources.QuotaMixin()
-        quota.raw_resource = mock.MagicMock()
-        self.assertEqual(quota.raw_resource, quota.id())
-
-    def test_name(self):
-        quota = resources.QuotaMixin()
-        quota.raw_resource = mock.MagicMock()
-        self.assertIsNone(quota.name())
-
-    def test_delete(self):
-        quota = resources.QuotaMixin()
-        mock_manager = mock.MagicMock()
-        quota._manager = lambda: mock_manager
-        quota.raw_resource = mock.MagicMock()
-
-        quota.delete()
-        mock_manager.delete.assert_called_once_with(quota.raw_resource)
-
-    def test_list(self):
+    @mock.patch("%s.identity.Identity" % BASE)
+    def test_list(self, mock_identity):
         quota = resources.QuotaMixin()
         quota.tenant_uuid = None
+        quota.user = mock.MagicMock()
         self.assertEqual([], quota.list())
+        self.assertFalse(mock_identity.called)
 
         quota.tenant_uuid = mock.MagicMock()
-        self.assertEqual([quota.tenant_uuid], quota.list())
+        self.assertEqual([mock_identity.return_value.get_project.return_value],
+                         quota.list())
+        mock_identity.assert_called_once_with(quota.user)
 
 
 class MagnumMixinTestCase(test.TestCase):
@@ -486,17 +474,97 @@ class NeutronPortTestCase(test.TestCase):
 
     def test_name(self):
         raw_res = {
-            "device_owner": "network:router_interface",
             "id": "some_id",
             "device_id": "dev_id",
-            "name": "foo"
         }
-        user = mock.MagicMock()
 
         self.assertIsInstance(
-            resources.NeutronPort(resource=raw_res, user=user).name(),
+            resources.NeutronPort(resource=raw_res,
+                                  user=mock.MagicMock()).name(),
             resources.base.NoName)
 
+        raw_res["name"] = "foo"
+        self.assertEqual("foo", resources.NeutronPort(
+            resource=raw_res, user=mock.MagicMock()).name())
+
+        raw_res["parent_name"] = "bar"
+        self.assertEqual("bar", resources.NeutronPort(
+            resource=raw_res, user=mock.MagicMock()).name())
+
+        del raw_res["name"]
+        self.assertEqual("bar", resources.NeutronPort(
+            resource=raw_res, user=mock.MagicMock()).name())
+
+    def test_list(self):
+
+        tenant_uuid = "uuuu-uuuu-iiii-dddd"
+
+        ports = [
+            # the case when 'name' is present, so 'device_owner' field is not
+            #   required
+            {"tenant_id": tenant_uuid, "id": "id1", "name": "foo"},
+            # 3 different cases when router_interface is an owner
+            {"tenant_id": tenant_uuid, "id": "id2",
+             "device_owner": "network:router_interface",
+             "device_id": "router-1"},
+            {"tenant_id": tenant_uuid, "id": "id3",
+             "device_owner": "network:router_interface_distributed",
+             "device_id": "router-1"},
+            {"tenant_id": tenant_uuid, "id": "id4",
+             "device_owner": "network:ha_router_replicated_interface",
+             "device_id": "router-2"},
+            # the case when gateway router is an owner
+            {"tenant_id": tenant_uuid, "id": "id5",
+             "device_owner": "network:router_gateway",
+             "device_id": "router-3"},
+            # the case when gateway router is an owner, but device_id is
+            #   invalid
+            {"tenant_id": tenant_uuid, "id": "id6",
+             "device_owner": "network:router_gateway",
+             "device_id": "aaaa"},
+            # the case when port was auto-created with floating-ip
+            {"tenant_id": tenant_uuid, "id": "id7",
+             "device_owner": "network:dhcp",
+             "device_id": "asdasdasd"},
+            # the case when port is from another tenant
+            {"tenant_id": "wrong tenant", "id": "id8", "name": "foo"},
+            # WTF port without any parent and name
+            {"tenant_id": tenant_uuid, "id": "id9", "device_owner": ""},
+        ]
+
+        routers = [
+            {"id": "router-1", "name": "Router-1", "tenant_id": tenant_uuid},
+            {"id": "router-2", "name": "Router-2", "tenant_id": tenant_uuid},
+            {"id": "router-3", "name": "Router-3", "tenant_id": tenant_uuid},
+            {"id": "router-4", "name": "Router-4", "tenant_id": tenant_uuid},
+            {"id": "router-5", "name": "Router-5", "tenant_id": tenant_uuid},
+        ]
+
+        expected_ports = []
+        for port in ports:
+            if port["tenant_id"] == tenant_uuid:
+                expected_ports.append(copy.deepcopy(port))
+                if ("device_id" in port and
+                        port["device_id"].startswith("router")):
+                    expected_ports[-1]["parent_name"] = [
+                        r for r in routers
+                        if r["id"] == port["device_id"]][0]["name"]
+
+        class FakeNeutronClient(object):
+
+            list_ports = mock.Mock()
+            list_routers = mock.Mock()
+
+        neutron = FakeNeutronClient
+        neutron.list_ports.return_value = {"ports": ports}
+        neutron.list_routers.return_value = {"routers": routers}
+
+        user = mock.Mock(neutron=neutron)
+        self.assertEqual(expected_ports, resources.NeutronPort(
+            user=user, tenant_uuid=tenant_uuid).list())
+        neutron.list_ports.assert_called_once_with()
+        neutron.list_routers.assert_called_once_with()
+
 
 @ddt.ddt
 class NeutronSecurityGroupTestCase(test.TestCase):
@@ -527,18 +595,10 @@ class NeutronSecurityGroupTestCase(test.TestCase):
 
 class NeutronQuotaTestCase(test.TestCase):
 
-    @mock.patch("%s.NeutronQuota._manager" % BASE)
-    def test_delete(self, mock_neutron_quota__manager):
-        user = mock.MagicMock()
-        resources.NeutronQuota(user=user, tenant_uuid="fake").delete()
-        mock_neutron_quota__manager().delete_quota.assert_called_once_with(
-            "fake")
-
-    def test__manager(self):
-        admin = mock.MagicMock(neutron=mock.Mock(return_value="foo"))
-        res = resources.NeutronQuota(admin=admin, tenant_uuid="fake")
-        res._manager()
-        self.assertEqual("foo", getattr(admin, res._service)())
+    def test_delete(self):
+        admin = mock.MagicMock()
+        resources.NeutronQuota(admin=admin, tenant_uuid="fake").delete()
+        admin.neutron.return_value.delete_quota.assert_called_once_with("fake")
 
 
 @ddt.ddt
@@ -672,6 +732,46 @@ class KeystoneMixinTestCase(test.TestCase):
         identity.return_value.list_some_resource2s.assert_called_once_with()
 
 
+class KeystoneEc2TestCase(test.TestCase):
+    def test_user_id_property(self):
+        user_client = mock.Mock()
+        admin_client = mock.Mock()
+
+        manager = resources.KeystoneEc2(user=user_client, admin=admin_client)
+
+        self.assertEqual(user_client.keystone.auth_ref.user_id,
+                         manager.user_id)
+
+    def test_list(self):
+        user_client = mock.Mock()
+        admin_client = mock.Mock()
+
+        with mock.patch("%s.identity.Identity" % BASE, autospec=True) as p:
+            identity = p.return_value
+            manager = resources.KeystoneEc2(user=user_client,
+                                            admin=admin_client)
+            self.assertEqual(identity.list_ec2credentials.return_value,
+                             manager.list())
+            p.assert_called_once_with(user_client)
+            identity.list_ec2credentials.assert_called_once_with(
+                manager.user_id)
+
+    def test_delete(self):
+        user_client = mock.Mock()
+        admin_client = mock.Mock()
+        raw_resource = mock.Mock()
+
+        with mock.patch("%s.identity.Identity" % BASE, autospec=True) as p:
+            manager = resources.KeystoneEc2(user=user_client,
+                                            admin=admin_client,
+                                            resource=raw_resource)
+            manager.delete()
+
+            p.assert_called_once_with(user_client)
+            p.return_value.delete_ec2credential.assert_called_once_with(
+                manager.user_id, access=raw_resource.access)
+
+
 class SwiftMixinTestCase(test.TestCase):
 
     def get_swift_mixin(self):
