@@ -185,16 +185,17 @@ class ImageGeneratorTestCase(test.ScenarioTestCase):
         images_ctx = images.ImageGenerator(self.context)
         images_ctx.cleanup()
 
-        glance_client = mock_clients.return_value.glance.return_value
-        glance_client.images.get.assert_has_calls([mock.call(i)
-                                                   for i in created_images])
         wrapper_calls = []
         wrapper_calls.extend([mock.call(mock_clients.return_value.glance,
                                         images_ctx)] * tenants_count)
-        wrapper_calls.extend(
-            [mock.call().delete_image(glance_client.images.get.return_value)] *
-            len(created_images))
         mock_wrap.assert_has_calls(wrapper_calls, any_order=True)
+
+        glance_client = mock_clients.return_value.glance.return_value
+        glance_client.images.delete.assert_has_calls([mock.call(i)
+                                                      for i in created_images])
+        glance_client.images.get.assert_has_calls([mock.call(i)
+                                                   for i in created_images])
+
         mock_clients.assert_has_calls(
             [mock.call(mock.ANY, api_info=api_versions)] * tenants_count,
             any_order=True)
