@@ -24,109 +24,6 @@ from tests.unit import test
 CTX = "rally.plugins.openstack.context.keystone.users"
 
 
-class UserContextMixinTestCase(test.TestCase):
-
-    def setUp(self):
-        super(self.__class__, self).setUp()
-        self.mixin = users.UserContextMixin()
-        self.mixin.context = {
-            "config": {
-                "users": {
-                    "user_choice_method": "random",
-                },
-            },
-        }
-
-    @mock.patch("%s.random.choice" % CTX, side_effect=lambda x: x[1])
-    def test_map_for_scenario_random(self, mock_choice):
-        self.mixin.context["config"]["users"]["user_choice_method"] = (
-            "random")
-        users_ = []
-        tenants = {}
-
-        for i in ("0", "1"):
-            tenants[i] = {"id": i, "name": i, "users": []}
-            for j in ("a", "b", "c"):
-                user = {
-                    "id": "%s_%s" % (i, j),
-                    "tenant_id": i,
-                    "credential": "credential",
-                }
-                users_.append(user)
-                tenants[i]["users"].append(user)
-
-        context = {
-            "admin": mock.MagicMock(),
-            "users": users_,
-            "tenants": tenants,
-            "some_random_key": {
-                "nested": mock.MagicMock(),
-                "one_more": 10
-            },
-            "config": {
-                "users": {
-                    "user_choice_method": "random",
-                },
-            },
-        }
-        chosen_tenant = context["tenants"][context["users"][1]["tenant_id"]]
-        expected_context = {
-            "admin": context["admin"],
-            "user": context["users"][1],
-            "tenant": chosen_tenant,
-            "some_random_key": context["some_random_key"],
-            "config": context["config"]
-        }
-
-        self.assertEqual(
-            expected_context,
-            self.mixin.map_for_scenario(context)
-        )
-
-    def test_user_choice_method_default(self):
-        self.mixin.context["config"]["users"]["user_choice_method"] = None
-
-        self.assertEqual(
-            "random",
-            self.mixin.user_choice_method
-        )
-
-    @mock.patch("%s.random.choice" % CTX,
-                side_effect=Exception("Should not be raised"))
-    def test_map_for_scenario_round_robin(self, mock_choice):
-        self.mixin.context["config"]["users"]["user_choice_method"] = (
-            "round_robin")
-        tenants = {s: {"name": s, "users": []} for s in ("0", "1")}
-        users_ = []
-        for tenant_id, tenant in tenants.items():
-            for i in ("0", "1"):
-                user = {"id": "%s_%s" % (tenant_id, i), "tenant_id": tenant_id,
-                        "endpoint": "endpoint"}
-                users_.append(user)
-                tenant["users"].append(user)
-        context = {
-            "admin": mock.MagicMock(),
-            "users": users_,
-            "tenants": tenants,
-            "some_random_key": {
-                "nested": mock.MagicMock(),
-                "one_more": 10
-            },
-            "config": {
-                "users": {
-                    "user_choice_method": "round_robin",
-                },
-            },
-        }
-        expected_ids = ["0_0", "1_0", "0_1", "1_1"] * 4
-        mapped_ids = []
-        for i in range(1, 17):
-            context["iteration"] = i
-            user = self.mixin.map_for_scenario(context)
-            mapped_ids.append(user["user"]["id"])
-        self.assertEqual(expected_ids, mapped_ids)
-
-
 class UserGeneratorTestCase(test.ScenarioTestCase):
 
     tenants_num = 1
@@ -155,10 +52,6 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
         self.osclients_patcher.stop()
         super(UserGeneratorTestCase, self).tearDown()
 
-    def test_is_user_context_mixin_subclass(self):
-        self.assertTrue(
-            issubclass(users.UserGenerator, users.UserContextMixin))
-
     @mock.patch("%s.network.wrap" % CTX)
     def test__remove_default_security_group_not_needed(self, mock_wrap):
         services = {"compute": consts.Service.NOVA}
@@ -288,8 +181,8 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
                                                           "nova-network")
         nova_admin.networks.disassociate.assert_called_once_with(networks[0])
 
-    @mock.patch("%s.keystone" % CTX)
-    def test__create_tenants(self, mock_keystone):
+    @mock.patch("%s.identity" % CTX)
+    def test__create_tenants(self, mock_identity):
         self.context["config"]["users"]["tenants"] = 1
         user_generator = users.UserGenerator(self.context)
         tenants = user_generator._create_tenants()
@@ -297,8 +190,8 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
         id, tenant = tenants.popitem()
         self.assertIn("name", tenant)
 
-    @mock.patch("%s.keystone" % CTX)
-    def test__create_users(self, mock_keystone):
+    @mock.patch("%s.identity" % CTX)
+    def test__create_users(self, mock_identity):
         self.context["config"]["users"]["users_per_tenant"] = 2
         user_generator = users.UserGenerator(self.context)
         user_generator.context["tenants"] = {"t1": {"id": "t1", "name": "t1"},
@@ -309,26 +202,26 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
             self.assertIn("id", user)
             self.assertIn("credential", user)
 
-    @mock.patch("%s.keystone" % CTX)
-    def test__delete_tenants(self, mock_keystone):
+    @mock.patch("%s.identity" % CTX)
+    def test__delete_tenants(self, mock_identity):
         user_generator = users.UserGenerator(self.context)
         user_generator.context["tenants"] = {"t1": {"id": "t1", "name": "t1"},
                                              "t2": {"id": "t2", "name": "t2"}}
         user_generator._delete_tenants()
         self.assertEqual(len(user_generator.context["tenants"]), 0)
 
-    @mock.patch("%s.keystone" % CTX)
-    def test__delete_tenants_failure(self, mock_keystone):
-        wrapped_keystone = mock_keystone.wrap.return_value
-        wrapped_keystone.delete_project.side_effect = Exception()
+    @mock.patch("%s.identity" % CTX)
+    def test__delete_tenants_failure(self, mock_identity):
+        identity_service = mock_identity.Identity.return_value
+        identity_service.delete_project.side_effect = Exception()
         user_generator = users.UserGenerator(self.context)
         user_generator.context["tenants"] = {"t1": {"id": "t1", "name": "t1"},
                                              "t2": {"id": "t2", "name": "t2"}}
         user_generator._delete_tenants()
         self.assertEqual(len(user_generator.context["tenants"]), 0)
 
-    @mock.patch("%s.keystone" % CTX)
-    def test__delete_users(self, mock_keystone):
+    @mock.patch("%s.identity" % CTX)
+    def test__delete_users(self, mock_identity):
         user_generator = users.UserGenerator(self.context)
         user1 = mock.MagicMock()
         user2 = mock.MagicMock()
@@ -336,10 +229,10 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
         user_generator._delete_users()
         self.assertEqual(len(user_generator.context["users"]), 0)
 
-    @mock.patch("%s.keystone" % CTX)
-    def test__delete_users_failure(self, mock_keystone):
-        wrapped_keystone = mock_keystone.wrap.return_value
-        wrapped_keystone.delete_user.side_effect = Exception()
+    @mock.patch("%s.identity" % CTX)
+    def test__delete_users_failure(self, mock_identity):
+        identity_service = mock_identity.Identity.return_value
+        identity_service.delete_user.side_effect = Exception()
         user_generator = users.UserGenerator(self.context)
         user1 = mock.MagicMock()
         user2 = mock.MagicMock()
@@ -347,10 +240,8 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
         user_generator._delete_users()
         self.assertEqual(len(user_generator.context["users"]), 0)
 
-    @mock.patch("%s.keystone" % CTX)
-    def test_setup_and_cleanup(self, mock_keystone):
-        wrapped_keystone = mock.MagicMock()
-        mock_keystone.wrap.return_value = wrapped_keystone
+    @mock.patch("%s.identity" % CTX)
+    def test_setup_and_cleanup(self, mock_identity):
         with users.UserGenerator(self.context) as ctx:
 
             ctx.setup()
@@ -359,17 +250,18 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
                              self.users_num)
             self.assertEqual(len(ctx.context["tenants"]),
                              self.tenants_num)
+            self.assertEqual("random", ctx.context["user_choice_method"])
 
         # Cleanup (called by content manager)
         self.assertEqual(len(ctx.context["users"]), 0)
         self.assertEqual(len(ctx.context["tenants"]), 0)
 
     @mock.patch("rally.common.broker.LOG.warning")
-    @mock.patch("%s.keystone" % CTX)
+    @mock.patch("%s.identity" % CTX)
     def test_setup_and_cleanup_with_error_during_create_user(
-            self, mock_keystone, mock_log_warning):
-        wrapped_keystone = mock_keystone.wrap.return_value
-        wrapped_keystone.create_user.side_effect = Exception
+            self, mock_identity, mock_log_warning):
+        identity_service = mock_identity.Identity.return_value
+        identity_service.create_user.side_effect = Exception()
         with users.UserGenerator(self.context) as ctx:
                 self.assertRaises(exceptions.ContextSetupFailure, ctx.setup)
                 mock_log_warning.assert_called_with(
@@ -378,10 +270,9 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
         # Ensure that tenants get deleted anyway
         self.assertEqual(0, len(ctx.context["tenants"]))
 
-    @mock.patch("%s.keystone" % CTX)
-    def test_users_and_tenants_in_context(self, mock_keystone):
-        wrapped_keystone = mock.MagicMock()
-        mock_keystone.wrap.return_value = wrapped_keystone
+    @mock.patch("%s.identity" % CTX)
+    def test_users_and_tenants_in_context(self, mock_identity):
+        identity_service = mock_identity.Identity.return_value
 
         credential = objects.Credential("foo_url", "foo", "foo_pass",
                                         https_insecure=True,
@@ -395,7 +286,7 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
         credential_dict = credential.to_dict(False)
         user_list = [mock.MagicMock(id="id_%d" % i)
                      for i in range(self.users_num)]
-        wrapped_keystone.create_user.side_effect = user_list
+        identity_service.create_user.side_effect = user_list
 
         with users.UserGenerator(tmp_context) as ctx:
             ctx.generate_random_name = mock.Mock()
@@ -430,8 +321,8 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
                 self.assertEqual(user["id"], orig_user.id)
                 self.assertEqual(user["tenant_id"], tenant_id)
 
-    @mock.patch("%s.keystone" % CTX)
-    def test_users_contains_correct_endpoint_type(self, mock_keystone):
+    @mock.patch("%s.identity" % CTX)
+    def test_users_contains_correct_endpoint_type(self, mock_identity):
         credential = objects.Credential(
             "foo_url", "foo", "foo_pass",
             endpoint_type=consts.EndpointType.INTERNAL)
@@ -453,8 +344,8 @@ class UserGeneratorTestCase(test.ScenarioTestCase):
         for user in users_:
             self.assertEqual("internal", user["credential"].endpoint_type)
 
-    @mock.patch("%s.keystone" % CTX)
-    def test_users_contains_default_endpoint_type(self, mock_keystone):
+    @mock.patch("%s.identity" % CTX)
+    def test_users_contains_default_endpoint_type(self, mock_identity):
         credential = objects.Credential("foo_url", "foo", "foo_pass")
         config = {
             "config": {
