@@ -15,6 +15,7 @@
 import mock
 
 from rally.plugins.openstack.context.sahara import sahara_input_data_sources
+from rally.plugins.openstack.scenarios.sahara import utils as sahara_utils
 from tests.unit import test
 
 CTX = "rally.plugins.openstack.context.sahara"
@@ -89,7 +90,9 @@ class SaharaInputDataSourcesTestCase(test.ScenarioTestCase):
 
         mock_cleanup.assert_called_once_with(
             names=["sahara.data_sources"],
-            users=self.context["users"])
+            users=self.context["users"],
+            superclass=sahara_utils.SaharaScenario,
+            task_id=self.context["task"]["uuid"])
 
     @mock.patch("requests.get")
     @mock.patch("%s.sahara_input_data_sources.osclients" % CTX)
@@ -155,4 +158,6 @@ class SaharaInputDataSourcesTestCase(test.ScenarioTestCase):
 
         mock_resource_manager.cleanup.assert_called_once_with(
             names=["sahara.data_sources"],
-            users=self.context["users"])
+            users=self.context["users"],
+            superclass=sahara_utils.SaharaScenario,
+            task_id=self.context["task"]["uuid"])
