@@ -48,12 +48,33 @@ class CinderServersTestCase(test.ScenarioTestCase):
         scenario._create_volume.assert_called_once_with(1, fakearg="f")
         scenario._list_volumes.assert_called_once_with(True)
 
+    def test_create_and_get_volume(self):
+        scenario = volumes.CreateAndGetVolume(self.context)
+        scenario._create_volume = mock.MagicMock()
+        scenario._get_volume = mock.MagicMock()
+        scenario.run(1, fakearg="f")
+        scenario._create_volume.assert_called_once_with(1, fakearg="f")
+        scenario._get_volume.assert_called_once_with(
+            scenario._create_volume.return_value.id)
+
     def test_list_volumes(self):
         scenario = volumes.ListVolumes(self.context)
         scenario._list_volumes = mock.MagicMock()
         scenario.run(True)
         scenario._list_volumes.assert_called_once_with(True)
 
+    def test_list_types(self):
+        scenario = volumes.ListTypes(self.context)
+        scenario._list_types = mock.MagicMock()
+        scenario.run(None, None)
+        scenario._list_types.assert_called_once_with(None, None)
+
+    def test_list_transfers(self):
+        scenario = volumes.ListTransfers(self.context)
+        scenario._list_transfers = mock.MagicMock()
+        scenario.run(True, None)
+        scenario._list_transfers.assert_called_once_with(True, None)
+
     def test_create_and_update_volume(self):
         volume_update_args = {"dispaly_name": "_updated"}
         scenario = volumes.CreateAndUpdateVolume(self.context)
@@ -65,6 +86,16 @@ class CinderServersTestCase(test.ScenarioTestCase):
         scenario._update_volume.assert_called_once_with(fake_volume,
                                                         **volume_update_args)
 
+    def test_create_volume_and_update_readonly_flag(self):
+        scenario = volumes.CreateVolumeAndUpdateReadonlyFlag(self.context)
+        fake_volume = mock.MagicMock()
+        scenario._create_volume = mock.MagicMock(return_value=fake_volume)
+        scenario._update_readonly_flag = mock.MagicMock()
+        scenario.run(1, None, True, fakearg="f")
+        scenario._create_volume.assert_called_once_with(1, fakearg="f")
+        scenario._update_readonly_flag.assert_called_once_with(
+            fake_volume.id, True)
+
     def test_create_and_delete_volume(self):
         fake_volume = mock.MagicMock()
 
@@ -276,7 +307,7 @@ class CinderServersTestCase(test.ScenarioTestCase):
                                                         fake_attach)
         scenario._delete_volume.assert_called_once_with(fake_volume)
 
-    def test_create_snapshot_and_attach_volume_use_volume_type(self):
+    def test_create_snapshot_and_attach_volume_use_volume_type_with_name(self):
         fake_volume = mock.MagicMock()
         fake_snapshot = mock.MagicMock()
         fake_server = mock.MagicMock()
@@ -299,13 +330,13 @@ class CinderServersTestCase(test.ScenarioTestCase):
         self.clients("nova").servers.get = mock.MagicMock(
             return_value=fake_server)
 
-        scenario.run(volume_type=True)
+        scenario.run(volume_type="fake_volume_type")
 
         # Make sure create volume's second arg was the correct volume type.
         # fake or none (randomly selected)
         self.assertTrue(scenario._create_volume.called)
         vol_type = scenario._create_volume.call_args_list[0][1]["volume_type"]
-        self.assertTrue(vol_type is fake.name or vol_type is None)
+        self.assertEqual(vol_type, "fake_volume_type")
         scenario._create_snapshot.assert_called_once_with(fake_volume.id,
                                                           False)
         scenario._delete_snapshot.assert_called_once_with(fake_snapshot)
@@ -633,3 +664,21 @@ class CinderServersTestCase(test.ScenarioTestCase):
             1, snapshot_id=fake_snapshot.id, fakearg="f")
         self.assertFalse(scenario._delete_snapshot.called)
         self.assertFalse(scenario._delete_volume.called)
+
+    @ddt.data({},
+              {"image": "img"})
+    @ddt.unpack
+    def test_create_and_accept_transfer(self, image=None):
+        fake_volume = mock.MagicMock()
+        fake_transfer = mock.MagicMock()
+        scenario = volumes.CreateAndAcceptTransfer(self._get_context())
+        scenario._create_volume = mock.MagicMock(return_value=fake_volume)
+        scenario._transfer_create = mock.MagicMock(return_value=fake_transfer)
+        scenario._transfer_accept = mock.MagicMock()
+        scenario.run(1, image=image, fakearg="fake")
+        expected = [mock.call(1, imageRef=image, fakearg="fake")
+                    if image else mock.call(1, fakearg="fake")]
+        scenario._create_volume.assert_has_calls(expected)
+        scenario._transfer_create.assert_called_once_with(fake_volume.id)
+        scenario._transfer_accept.assert_called_once_with(
+            fake_transfer.id, fake_transfer.auth_key)
