@@ -16,6 +16,7 @@
 import ddt
 import mock
 
+from rally import exceptions
 from rally.plugins.openstack.scenarios.nova import flavors
 from tests.unit import test
 
@@ -36,17 +37,57 @@ class NovaFlavorsTestCase(test.TestCase):
               {"is_public": False, "fakeargs": "fakeargs"})
     @ddt.unpack
     def test_create_and_list_flavor_access(self, **kwargs):
+        # Common parameters
+        ram = 100
+        vcpus = 1
+        disk = 1
+
         scenario = flavors.CreateAndListFlavorAccess()
         scenario._create_flavor = mock.Mock()
         scenario._list_flavor_access = mock.Mock()
-        scenario.run(ram=100, vcpus=1, disk=1, **kwargs)
+
+        # Positive case:
+        scenario.run(ram, vcpus, disk, **kwargs)
         kwargs.pop("is_public", None)
-        scenario._create_flavor.assert_called_once_with(100, 1, 1,
+        scenario._create_flavor.assert_called_once_with(ram, vcpus, disk,
                                                         is_public=False,
                                                         **kwargs)
         scenario._list_flavor_access.assert_called_once_with(
             scenario._create_flavor.return_value.id)
 
+        # Negative case1: flavor wasn't created
+        scenario._create_flavor.return_value = None
+        self.assertRaises(exceptions.RallyAssertionError, scenario.run,
+                          ram, vcpus, disk, **kwargs)
+        scenario._create_flavor.assert_called_with(ram, vcpus, disk,
+                                                   is_public=False,
+                                                   **kwargs)
+
+    def test_create_flavor_add_tenant_access(self, **kwargs):
+        flavor = mock.MagicMock()
+        context = {"user": {"tenant_id": "fake"},
+                   "tenant": {"id": "fake"}}
+        scenario = flavors.CreateFlavorAndAddTenantAccess()
+        scenario.context = context
+        scenario.generate_random_name = mock.MagicMock()
+        scenario._create_flavor = mock.MagicMock(return_value=flavor)
+        scenario._add_tenant_access = mock.MagicMock()
+
+        # Positive case:
+        scenario.run(ram=100, vcpus=1, disk=1, **kwargs)
+
+        scenario._create_flavor.assert_called_once_with(100, 1, 1,
+                                                        **kwargs)
+        scenario._add_tenant_access.assert_called_once_with(flavor.id,
+                                                            "fake")
+
+        # Negative case1: flavor wasn't created
+        scenario._create_flavor.return_value = None
+        self.assertRaises(exceptions.RallyAssertionError, scenario.run,
+                          100, 1, 1, **kwargs)
+        scenario._create_flavor.assert_called_with(100, 1, 1,
+                                                   **kwargs)
+
     def test_create_flavor(self):
         scenario = flavors.CreateFlavor()
         scenario._create_flavor = mock.MagicMock()
@@ -64,6 +105,16 @@ class NovaFlavorsTestCase(test.TestCase):
         scenario._get_flavor.assert_called_once_with(
             scenario._create_flavor.return_value.id)
 
+    def test_create_and_delete_flavor(self, **kwargs):
+        scenario = flavors.CreateAndDeleteFlavor()
+        scenario._create_flavor = mock.Mock()
+        scenario._delete_flavor = mock.Mock()
+        scenario.run(ram=100, vcpus=1, disk=1, **kwargs)
+
+        scenario._create_flavor.assert_called_once_with(100, 1, 1, **kwargs)
+        scenario._delete_flavor.assert_called_once_with(
+            scenario._create_flavor.return_value.id)
+
     def test_create_flavor_and_set_keys(self):
         scenario = flavors.CreateFlavorAndSetKeys()
         scenario._create_flavor = mock.MagicMock()
