@@ -37,6 +37,12 @@ class QuotasTestCase(test.ScenarioTestCase):
         scenario.run()
         scenario._get_quotas.assert_called_once_with("nova", "fake")
 
+    def test_cinder_get(self):
+        scenario = quotas.CinderGet(self.context)
+        scenario._get_quotas = mock.MagicMock()
+        scenario.run()
+        scenario._get_quotas.assert_called_once_with("cinder", "fake")
+
     def test_nova_update(self):
         scenario = quotas.NovaUpdate(self.context)
         scenario._update_quotas = mock.MagicMock()
