@@ -61,8 +61,8 @@ class TaskAPITestCase(test.TestCase):
     @mock.patch("rally.api.objects.Task")
     @mock.patch("rally.api.objects.Deployment.get",
                 return_value=fakes.FakeDeployment(uuid="deployment_uuid",
-                                                  admin=mock.MagicMock(),
-                                                  users=[]))
+                                                  admin="fake_admin",
+                                                  users=["fake_user"]))
     @mock.patch("rally.api.engine.TaskEngine")
     def test_validate(
             self, mock_task_engine, mock_deployment_get, mock_task):
@@ -70,8 +70,7 @@ class TaskAPITestCase(test.TestCase):
 
         mock_task_engine.assert_has_calls([
             mock.call("config", mock_task.return_value,
-                      admin=mock_deployment_get.return_value["admin"],
-                      users=[]),
+                      mock_deployment_get.return_value),
             mock.call().validate()
         ])
 
@@ -83,9 +82,7 @@ class TaskAPITestCase(test.TestCase):
 
     @mock.patch("rally.api.objects.Task")
     @mock.patch("rally.api.objects.Deployment",
-                return_value=fakes.FakeDeployment(uuid="deployment_uuid",
-                                                  admin=mock.MagicMock(),
-                                                  users=[]))
+                return_value=fakes.FakeDeployment(uuid="deployment_uuid"))
     @mock.patch("rally.api.engine.TaskEngine")
     def test_validate_engine_exception(self, mock_task_engine,
                                        mock_deployment, mock_task):
@@ -153,7 +150,9 @@ class TaskAPITestCase(test.TestCase):
         self.assertEqual("2", api._Task.render_template(template))
 
     @mock.patch("rally.common.objects.Deployment.get",
-                return_value={"uuid": "b0d9cd6c-2c94-4417-a238-35c7019d0257"})
+                return_value={
+                    "uuid": "b0d9cd6c-2c94-4417-a238-35c7019d0257",
+                    "status": consts.DeployStatus.DEPLOY_FINISHED})
     @mock.patch("rally.common.objects.Task")
     def test_create(self, mock_task, mock_deployment_get):
         tag = "a"
@@ -161,12 +160,23 @@ class TaskAPITestCase(test.TestCase):
         mock_task.assert_called_once_with(
             deployment_uuid=mock_deployment_get.return_value["uuid"], tag=tag)
 
+    @mock.patch("rally.common.objects.Deployment.get",
+                return_value={
+                    "name": "xxx_name",
+                    "uuid": "u_id",
+                    "status": consts.DeployStatus.DEPLOY_INIT})
+    def test_create_on_unfinished_deployment(self, mock_deployment_get):
+        deployment_id = mock_deployment_get.return_value["uuid"]
+        tag = "a"
+        self.assertRaises(exceptions.DeploymentNotFinishedStatus,
+                          api._Task.create, deployment_id, tag)
+
     @mock.patch("rally.api.objects.Task",
                 return_value=fakes.FakeTask(uuid="some_uuid"))
     @mock.patch("rally.api.objects.Deployment.get",
                 return_value=fakes.FakeDeployment(uuid="deployment_uuid",
-                                                  admin=mock.MagicMock(),
-                                                  users=[]))
+                                                  admin="fake_admin",
+                                                  users=["fake_user"]))
     @mock.patch("rally.api.engine.TaskEngine")
     def test_start(self, mock_task_engine, mock_deployment_get,
                    mock_task):
@@ -174,8 +184,8 @@ class TaskAPITestCase(test.TestCase):
 
         mock_task_engine.assert_has_calls([
             mock.call("config", mock_task.return_value,
-                      admin=mock_deployment_get.return_value["admin"],
-                      users=[], abort_on_sla_failure=False),
+                      mock_deployment_get.return_value,
+                      abort_on_sla_failure=False),
             mock.call().run(),
         ])
 
@@ -190,8 +200,8 @@ class TaskAPITestCase(test.TestCase):
                                             temporary=True))
     @mock.patch("rally.api.objects.Deployment.get",
                 return_value=fakes.FakeDeployment(uuid="deployment_uuid",
-                                                  admin=mock.MagicMock(),
-                                                  users=[]))
+                                                  admin="fake_admin",
+                                                  users=["fake_user"]))
     def test_start_temporary_task(self, mock_deployment_get,
                                   mock_task):
 
@@ -216,7 +226,7 @@ class TaskAPITestCase(test.TestCase):
     def test_abort_sync(self, soft, mock_task, mock_time):
         mock_task.get_status.side_effect = (
             consts.TaskStatus.INIT,
-            consts.TaskStatus.VERIFYING,
+            consts.TaskStatus.VALIDATING,
             consts.TaskStatus.RUNNING,
             consts.TaskStatus.ABORTING,
             consts.TaskStatus.SOFT_ABORTING,
@@ -249,7 +259,7 @@ class TaskAPITestCase(test.TestCase):
                "expected_status": consts.TaskStatus.FINISHED},
               {"task_status": consts.TaskStatus.INIT,
                "expected_status": consts.TaskStatus.FINISHED},
-              {"task_status": consts.TaskStatus.VERIFYING,
+              {"task_status": consts.TaskStatus.VALIDATING,
                "expected_status": consts.TaskStatus.FINISHED},
               {"task_status": consts.TaskStatus.ABORTING,
                "expected_status": consts.TaskStatus.FINISHED},
@@ -261,13 +271,13 @@ class TaskAPITestCase(test.TestCase):
                "expected_status": None},
               {"task_status": consts.TaskStatus.FINISHED,
                "expected_status": None},
-              {"task_status": consts.TaskStatus.FAILED,
+              {"task_status": consts.TaskStatus.CRASHED,
                "expected_status": None},
               {"task_status": "strange value",
                "force": True, "expected_status": None},
               {"task_status": consts.TaskStatus.INIT,
                "force": True, "expected_status": None},
-              {"task_status": consts.TaskStatus.VERIFYING,
+              {"task_status": consts.TaskStatus.VALIDATING,
                "force": True, "expected_status": None},
               {"task_status": consts.TaskStatus.RUNNING,
                "force": True, "expected_status": None},
@@ -279,7 +289,7 @@ class TaskAPITestCase(test.TestCase):
                "force": True, "expected_status": None},
               {"task_status": consts.TaskStatus.FINISHED,
                "force": True, "expected_status": None},
-              {"task_status": consts.TaskStatus.FAILED,
+              {"task_status": consts.TaskStatus.CRASHED,
                "force": True, "expected_status": None})
     @ddt.unpack
     @mock.patch("rally.api.objects.Task.get_status")
@@ -318,9 +328,9 @@ class TaskAPITestCase(test.TestCase):
 class BaseDeploymentTestCase(test.TestCase):
     def setUp(self):
         super(BaseDeploymentTestCase, self).setUp()
-        self.deployment_config = FAKE_DEPLOYMENT_CONFIG
+        self.deployment_config = copy.deepcopy(FAKE_DEPLOYMENT_CONFIG)
         self.deployment_uuid = "599bdf1d-fe77-461a-a810-d59b1490f4e3"
-        admin_credential = FAKE_DEPLOYMENT_CONFIG.copy()
+        admin_credential = copy.deepcopy(FAKE_DEPLOYMENT_CONFIG)
         admin_credential.pop("type")
         admin_credential["endpoint"] = None
         admin_credential.update(admin_credential.pop("admin"))
@@ -332,8 +342,7 @@ class BaseDeploymentTestCase(test.TestCase):
             "uuid": self.deployment_uuid,
             "name": "fake_name",
             "config": self.deployment_config,
-            "admin": self.credentials["admin"],
-            "users": []
+            "credentials": {"openstack": [self.credentials]}
         }
 
 
@@ -345,18 +354,16 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
                     mock_deployment_create, mock_deployment_update):
         mock_deployment_create.return_value = self.deployment
         mock_deployment_update.return_value = self.deployment
-        api._Deployment.create(self.deployment_config, "fake_deployment")
+        dep = api._Deployment.create(self.deployment_config, "fake_deployment")
+        self.assertIsInstance(dep, objects.Deployment)
         mock_deployment_create.assert_called_once_with({
             "name": "fake_deployment",
             "config": self.deployment_config,
         })
-        mock_engine_validate.assert_called_with()
+        mock_engine_validate.assert_called_once_with()
         mock_deployment_update.assert_has_calls([
             mock.call(self.deployment_uuid,
-                      {"credentials": [["openstack",
-                                        {"admin": self.credentials["admin"],
-                                         "users": self.credentials["users"]}]]
-                       })
+                      {"credentials": {"openstack": [self.credentials]}})
         ])
 
     @mock.patch("rally.common.objects.deploy.db.deployment_update")
@@ -415,11 +422,11 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
         api._Deployment.recreate(self.deployment_uuid)
         mock_deployment_get.assert_called_once_with(self.deployment_uuid)
         mock_deployment_update.assert_has_calls([
-            mock.call(self.deployment_uuid,
-                      {"credentials": [["openstack",
-                                        {"admin": self.credentials["admin"],
-                                         "users": self.credentials["users"]}]]
-                       })
+            mock.call(
+                self.deployment_uuid,
+                {"credentials":
+                    {"openstack": [{"admin": self.credentials["admin"],
+                                    "users": self.credentials["users"]}]}})
         ])
 
     @mock.patch("rally.common.objects.deploy.db.deployment_update")
@@ -488,8 +495,9 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
         sample_credential = objects.Credential("http://192.168.1.1:5000/v2.0/",
                                                "admin",
                                                "adminpass").to_dict()
-        deployment = {"admin": sample_credential,
-                      "users": [sample_credential]}
+        deployment = mock.Mock(spec=objects.Deployment)
+        deployment.get_credentials_for.return_value = {
+            "admin": sample_credential, "users": [sample_credential]}
         api._Deployment.check(deployment)
         mock_keystone_create_client.assert_called_with()
         mock_clients_services.assert_called_once_with()
@@ -499,7 +507,7 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
                                                "admin",
                                                "adminpass").to_dict()
         sample_credential["not-exist-key"] = "error"
-        deployment = {"admin": sample_credential}
+        deployment = mock.Mock(spec=objects.Deployment)
         self.assertRaises(TypeError, api._Deployment.check, deployment)
 
     @mock.patch("rally.osclients.Clients.services")
@@ -507,7 +515,9 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
         sample_credential = objects.Credential("http://192.168.1.1:5000/v2.0/",
                                                "admin",
                                                "adminpass").to_dict()
-        deployment = {"admin": sample_credential}
+        deployment = mock.Mock(spec=objects.Deployment)
+        deployment.get_credentials_for.return_value = {
+            "admin": sample_credential, "users": []}
         refused = keystone_exceptions.ConnectionRefused()
         mock_clients_services.side_effect = refused
         self.assertRaises(
@@ -1232,8 +1242,12 @@ class VerificationAPITestCase(test.TestCase):
         self.assertTrue(averification.set_failed.called)
 
     @mock.patch("rally.api._Verifier.get")
+    @mock.patch("rally.api.objects.Deployment.get",
+                return_value=fakes.FakeDeployment(
+                    uuid="deployment_uuid",
+                    status=consts.DeployStatus.DEPLOY_FINISHED))
     def test_start_failed_due_to_wrong_status_of_verifier(
-            self, mock___verifier_get):
+            self, mock_deployment_get, mock___verifier_get):
         verifier_id = "vuuuiiddd"
         deployment_id = "duuuiidd"
         verifier_obj = mock___verifier_get.return_value
@@ -1252,7 +1266,12 @@ class VerificationAPITestCase(test.TestCase):
     @mock.patch("rally.api.objects.Verification.create")
     @mock.patch("rally.api._Verifier.configure")
     @mock.patch("rally.api._Verifier.get")
-    def test_start_with_configuring(self, mock___verifier_get, mock_configure,
+    @mock.patch("rally.api.objects.Deployment.get",
+                return_value=fakes.FakeDeployment(
+                    uuid="deployment_uuid",
+                    status=consts.DeployStatus.DEPLOY_FINISHED))
+    def test_start_with_configuring(self, mock_deployment_get,
+                                    mock___verifier_get, mock_configure,
                                     mock_verification_create):
         verifier_id = "vuuuiiddd"
         deployment_id = "duuuiidd"
@@ -1261,14 +1280,19 @@ class VerificationAPITestCase(test.TestCase):
         verifier_obj.manager.is_configured.return_value = False
 
         api._Verification.start(verifier_id, deployment_id)
+        mock_deployment_get.assert_called_once_with(deployment_id)
         verifier_obj.set_deployment.assert_called_once_with(deployment_id)
         mock_configure.assert_called_once_with(verifier_obj, deployment_id)
 
     @mock.patch("rally.api.objects.Verification.create")
     @mock.patch("rally.api._Verifier.configure")
     @mock.patch("rally.api._Verifier.get")
-    def test_start(self, mock___verifier_get, mock_configure,
-                   mock_verification_create):
+    @mock.patch("rally.api.objects.Deployment.get",
+                return_value=fakes.FakeDeployment(
+                    uuid="deployment_uuid",
+                    status=consts.DeployStatus.DEPLOY_FINISHED))
+    def test_start(self, mock_deployment_get, mock___verifier_get,
+                   mock_configure, mock_verification_create):
         verifier_id = "vuuuiiddd"
         deployment_id = "duuuiidd"
         tags = ["foo", "bar"]
@@ -1280,6 +1304,7 @@ class VerificationAPITestCase(test.TestCase):
         api._Verification.start(verifier_id, deployment_id, tags=tags,
                                 **run_args)
 
+        mock_deployment_get.assert_called_once_with(deployment_id)
         verifier_obj.set_deployment.assert_called_once_with(deployment_id)
         verifier_obj.manager.validate.assert_called_once_with(run_args)
         mock_verification_create.assert_called_once_with(
@@ -1300,10 +1325,29 @@ class VerificationAPITestCase(test.TestCase):
 
         self.assertFalse(mock_configure.called)
 
+    @mock.patch("rally.api.objects.Deployment.get",
+                return_value=fakes.FakeDeployment(
+                    name="xxx_name",
+                    uuid="deployment_uuid",
+                    status=consts.DeployStatus.DEPLOY_INIT))
+    def test_start_on_unfinished_deployment(self, mock_deployment_get):
+        verifier_id = "v_id"
+        deployment_id = mock_deployment_get.return_value["uuid"]
+        tags = ["foo", "bar"]
+        run_args = {"arg": "value"}
+        self.assertRaises(exceptions.DeploymentNotFinishedStatus,
+                          api._Verification.start, verifier_id, deployment_id,
+                          tags=tags, **run_args)
+
     @mock.patch("rally.api.objects.Verification.create")
     @mock.patch("rally.api._Verifier.configure")
     @mock.patch("rally.api._Verifier.get")
-    def test_start_failed_to_run(self, mock___verifier_get, mock_configure,
+    @mock.patch("rally.api.objects.Deployment.get",
+                return_value=fakes.FakeDeployment(
+                    uuid="deployment_uuid",
+                    status=consts.DeployStatus.DEPLOY_FINISHED))
+    def test_start_failed_to_run(self, mock_deployment_get,
+                                 mock___verifier_get, mock_configure,
                                  mock_verification_create):
         verifier_id = "vuuuiiddd"
         deployment_id = "duuuiidd"
@@ -1350,7 +1394,7 @@ class VerificationAPITestCase(test.TestCase):
 
         api._Verification.rerun("uuid")
         mock___verification_start.assert_called_once_with(
-            "v_uuid", "d_uuid", load_list=tests.keys())
+            "v_uuid", "d_uuid", load_list=tests.keys(), tags=None)
 
     @mock.patch("rally.api._Verification.start")
     @mock.patch("rally.api._Deployment.get")
@@ -1370,7 +1414,7 @@ class VerificationAPITestCase(test.TestCase):
         api._Verification.rerun("uuid", failed=True)
         expected_tests = [t for t, r in tests.items() if r["status"] == "fail"]
         mock___verification_start.assert_called_once_with(
-            "v_uuid", "d_uuid", load_list=expected_tests)
+            "v_uuid", "d_uuid", load_list=expected_tests, tags=None)
 
     @mock.patch("rally.api._Verification.get")
     def test_rerun_failed_tests_raise_exc(
